@@ -2,14 +2,14 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: html.php,v 1.43 2004/01/31 00:56:18 yeupou Exp $
+// $Id: html.php,v 1.45 2004/02/29 18:37:42 toddy Exp $
+//
 //
-// 
 // Copyright 1999-2000 (c) The SourceForge Crew
 //
 //
 //  Copyright (C) 2000-2003 Free Software Foundation
-// 
+//
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either version 2
@@ -28,50 +28,50 @@
 //
 //
 
-function html_nextprev ($search_url, $rows, $rows_returned) 
+function html_nextprev ($search_url, $rows, $rows_returned)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_nextprev ($search_url, $rows, $rows_returned) ';
   global $offset, $max_rows;
-  
-  if (($rows_returned > $rows) || ($offset != 0))  
+
+  if (($rows_returned > $rows) || ($offset != 0))
     {
       print "\n<br><h5 align=\"center\">\n";
-      
-      if ($offset != 0) 
+
+      if ($offset != 0)
 	{
 	  print '<a href="'.$search_url.'&amp;offset='.($offset-$rows).'&amp;max_rows='.$max_rows.'">';
 	  print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previous.png" border="0" alt="'._("Previous Results").'">'._("Previous Results").'</a>';
-	  
-	} 
-      else 
+
+	}
+      else
 	{
 	  print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previousgrey.png" border="0" alt="'._("Previous Results").'"><font class="italic">'._("Previous Results").'</font>';
 	}
-      
+
       print "&nbsp; &nbsp; &nbsp;";
-      
-      if ($rows_returned > $rows) 
+
+      if ($rows_returned > $rows)
 	{
 	  print '<a href="'.$search_url.'&amp;offset='.($offset+$rows).'&amp;max_rows='.$max_rows.'">';
 	  print _("Next Results").' <img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/next.png" border="0" alt="'._("Next Results").'"></a>';
-	} 
-      else 
+	}
+      else
 	{
 	  print '<font class="italic">'._("Next Results").'</font> <img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/nextgrey.png" border="0" alt="'._("Next Results").'">';
 	}
-      
+
       print "</h5>\n";
     }
 }
 
-function html_feedback_top() 
+function html_feedback_top()
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_feedback_top() ';
-  if ($GLOBALS[feedback]) 
+  if ($GLOBALS[feedback])
     {  print '<h3 class="feedback">'.$GLOBALS[feedback].'</h3>'; }
-  if ($GLOBALS[ffeedback]) 
+  if ($GLOBALS[ffeedback])
     {  print '<h3 class="feedbackerror">'.$GLOBALS[ffeedback].'</h3>'; }
-  if ($GLOBALS[sys_debug_on] && $GLOBALS[debug]) 
+  if ($GLOBALS[sys_debug_on] && $GLOBALS[debug])
     {  print '<h3 class="feedbackerror">DEBUG information: '.$GLOBALS[debug].'</h3>'; }
   // yeupou@gnu.org 2003-11-03:
   // We unset feedback so there will be a bottom feedback only if something
@@ -82,36 +82,36 @@ function html_feedback_top()
   unset($GLOBALS[feedback],$GLOBALS[ffeedback],$GLOBALS[debug]);
 }
 
-function html_feedback_bottom() 
+function html_feedback_bottom()
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_feedback_bottom() ';
-  if ($GLOBALS[feedback]) 
+  if ($GLOBALS[feedback])
     {  print '<h3 class="feedback">'.$GLOBALS[feedback].'</h3>'; }
-  if ($GLOBALS[ffeedback]) 
+  if ($GLOBALS[ffeedback])
     {  print '<h3 class="feedbackerror">'.$GLOBALS[ffeedback].'</h3>'; }
-  if ($GLOBALS[sys_debug_on] && $GLOBALS[debug]) 
+  if ($GLOBALS[sys_debug_on] && $GLOBALS[debug])
     {  print '<h3 class="feedbackerror">DEBUG information: '.$GLOBALS[debug].'</h3>'; }
 }
 
-function html_a_group($grp) 
+function html_a_group($grp)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_a_group($grp) ';
   print '<A href="'.$GLOBALS['sys_home'].'project/?group_id='.$grp.'">' . group_getname($grp) . '</A>';
 }
 
-function html_blankimage($height,$width) 
+function html_blankimage($height,$width)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_blankimage($height,$width) ';
   return html_image('blank.png',array('height'=>$height,'width'=>$width,'alt'=>' '));
 }
 
-function html_image($src,$args,$display=1) 
+function html_image($src,$args,$display=1)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_image($src,$args,$display=1) ';
   GLOBAL $img_size;
   $return = ('<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$src.'"');
   reset($args);
-  while(list($k,$v) = each($args)) 
+  while(list($k,$v) = each($args))
     {
       $return .= ' '.$k.'="'.$v.'"';
     }
@@ -120,17 +120,17 @@ function html_image($src,$args,$display=1)
   if (!$args['border']) $return .= (' border="0"');
 
   // ## if no height AND no width tag, insert em both
-  if (!$args['height'] && !$args['width']) 
+  if (!$args['height'] && !$args['width'])
     {
       /* Check to see if we've already fetched the image data */
       if($img_size){
 	if(!$img_size[$src] && is_file($GLOBALS['sys_urlroot'].'images/'.$src)){
 	  $img_size[$src] = @getimagesize($GLOBALS['sys_urlroot'].'images/'.$src);
 	}
-      } 
-      else 
+      }
+      else
 	{
-	  if(is_file($GLOBALS['sys_urlroot'].'images/'.$src)){		
+	  if(is_file($GLOBALS['sys_urlroot'].'images/'.$src)){
 	    $img_size[$src] = @getimagesize($GLOBALS['sys_urlroot'].'images/'.$src);
 	  }
 	}
@@ -141,24 +141,24 @@ function html_image($src,$args,$display=1)
   if (!$args['alt']) $return .= " alt=\"$src\"";
 
   $return .= ('>');
-  if ($display) 
+  if ($display)
     {
       print $return;
-    } 
-  else 
+    }
+  else
     {
       return $return;
     }
 }
 
-function html_get_timezone_popup ($title='timezone',$selected='xzxzxzx') 
+function html_get_timezone_popup ($title='timezone',$selected='xzxzxzx')
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_get_timezone_popup ';
   global $TZs;
   return html_build_select_box_from_arrays ($TZs,$TZs,$title,$selected,false);
 }
 
-function html_build_list_table_top ($title_arr,$links_arr=false) 
+function html_build_list_table_top ($title_arr,$links_arr=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_list_table_top ';
   /*
@@ -174,17 +174,17 @@ function html_build_list_table_top ($title_arr,$links_arr=false)
 		<tr>';
 
   $count=count($title_arr);
-  if ($links_arr) 
+  if ($links_arr)
     {
-      for ($i=0; $i<$count; $i++) 
+      for ($i=0; $i<$count; $i++)
 	{
 	  $return .= '
 			<td class="boxtitle"><a class=sortbutton href="'.$links_arr[$i].'">'.$title_arr[$i].'</a></td>';
 	}
-    } 
-  else 
+    }
+  else
     {
-      for ($i=0; $i<$count; $i++) 
+      for ($i=0; $i<$count; $i++)
 	{
 	  $return .= '
 			<td class="boxtitle">'.$title_arr[$i].'</td>';
@@ -193,29 +193,29 @@ function html_build_list_table_top ($title_arr,$links_arr=false)
   return $return.'</tr>';
 }
 
-function html_get_alt_row_color ($i) 
+function html_get_alt_row_color ($i)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_get_alt_row_color ($i) ';
   GLOBAL $HTML;
-  if ($i % 2 == 0) 
+  if ($i % 2 == 0)
     {
       return 'boxitemalt';
-    } 
-  else 
+    }
+  else
     {
       return 'boxitem';
     }
 }
 
 //deprecated
-function utils_get_alt_row_color ($i) 
+function utils_get_alt_row_color ($i)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':utils_get_alt_row_color ($i) ';
   return html_get_alt_row_color ($i);
 }
 
 
-function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz',$samevals = 0) 
+function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz',$samevals = 0)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_select_box_from_array ';
   /*
@@ -232,20 +232,20 @@ function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz
 
   $rows=count($vals);
 
-  for ($i=0; $i<$rows; $i++) 
+  for ($i=0; $i<$rows; $i++)
     {
-      if ( $samevals ) 
+      if ( $samevals )
 	{
 	  $return .= "\n\t\t<option value=\"" . $vals[$i] . "\"";
-	  if ($vals[$i] == $checked_val) 
+	  if ($vals[$i] == $checked_val)
 	    {
 	      $return .= ' selected';
 	    }
-	} 
-      else 
+	}
+      else
 	{
 	  $return .= "\n\t\t<option value=\"" . $i .'"';
-	  if ($i == $checked_val) 
+	  if ($i == $checked_val)
 	    {
 	      $return .= ' selected';
 	    }
@@ -258,7 +258,7 @@ function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz
   return $return;
 }
 
-function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_val='xzxz',$show_100=true,$text_100='None', $show_any=false,$text_any='Any') 
+function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_val='xzxz',$show_100=true,$text_100='None', $show_any=false,$text_any='Any')
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_select_box_from_arrays ';
   /*
@@ -296,49 +296,49 @@ function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_v
 
 
   //we don't always want the default any  row shown
-  if ($show_any) 
+  if ($show_any)
     {
       $selected = ( $checked_val == 0 ? 'SELECTED':'');
       $return .= "\n<OPTION VALUE=\"0\" $selected>$text_any </OPTION>";
     }
 
   //we don't always want the default 100 row shown
-  if ($show_100) 
+  if ($show_100)
     {
       $selected = ( $checked_val == 100 ? 'SELECTED':'');
       $return .= "\n<OPTION VALUE=\"100\" $selected>$text_100 </OPTION>";
     }
 
   $rows=count($vals);
-  if (count($texts) != $rows) 
+  if (count($texts) != $rows)
     {
       $return .= 'ERROR - uneven row counts';
     }
 
-  for ($i=0; $i<$rows; $i++) 
+  for ($i=0; $i<$rows; $i++)
     {
       //  uggh - sorry - don't show the 100 row and Any row
       //  if it was shown above, otherwise do show it
-      if ( (($vals[$i] != '100') && ($vals[$i] != '0')) || 
+      if ( (($vals[$i] != '100') && ($vals[$i] != '0')) ||
 	   ($vals[$i] == '100' && !$show_100) ||
-	   ($vals[$i] == '0' && !$show_any) ) 
+	   ($vals[$i] == '0' && !$show_any) )
 	{
 	  $return .= '
 				<OPTION VALUE="'.$vals[$i].'"';
-	  if ($vals[$i] == $checked_val) 
+	  if ($vals[$i] == $checked_val)
 	    {
 	      $return .= ' SELECTED';
 	    }
 	  $return .= '>'.$texts[$i].'</OPTION>';
 	}
-		
+
     }
   $return .= '
 		</SELECT>';
   return $return;
 }
 
-function html_build_select_box ($result, $name, $checked_val="xzxz",$show_100=true,$text_100='None',$show_any=false,$text_any='Any') 
+function html_build_select_box ($result, $name, $checked_val="xzxz",$show_100=true,$text_100='None',$show_any=false,$text_any='Any')
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_select_box  ';
   /*
@@ -357,7 +357,7 @@ function html_build_select_box ($result, $name, $checked_val="xzxz",$show_100=tr
   return html_build_select_box_from_arrays (utils_result_column_to_array($result,0),utils_result_column_to_array($result,1),$name,$checked_val,$show_100,$text_100,$show_any,$text_any);
 }
 
-function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',$show_100=true,$text_100='None', $show_any=false,$text_any='Any',$show_value=true) 
+function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',$show_100=true,$text_100='None', $show_any=false,$text_any='Any',$show_value=true)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_multiple_select_box ';
   /*
@@ -383,13 +383,13 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
   /*
 		Put in the Any box
   */
-  if ($show_any) 
+  if ($show_any)
     {
       $return .= '
 		<OPTION VALUE="0"';
-      for ($j=0; $j<$checked_count; $j++) 
+      for ($j=0; $j<$checked_count; $j++)
 	{
-	  if ($checked_array[$j] == '0') 
+	  if ($checked_array[$j] == '0')
 	    {
 	      $return .= ' SELECTED';
 	    }
@@ -400,13 +400,13 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
   /*
 		Put in the default NONE box
   */
-  if ($show_100) 
+  if ($show_100)
     {
       $return .= '
 		<OPTION VALUE="100"';
-      for ($j=0; $j<$checked_count; $j++) 
+      for ($j=0; $j<$checked_count; $j++)
 	{
-	  if ($checked_array[$j] == '100') 
+	  if ($checked_array[$j] == '100')
 	    {
 	      $return .= ' SELECTED';
 	    }
@@ -416,9 +416,9 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
 
   $rows=db_numrows($result);
 
-  for ($i=0; $i<$rows; $i++) 
+  for ($i=0; $i<$rows; $i++)
     {
-      if (db_result($result,$i,0) != '100') 
+      if (db_result($result,$i,0) != '100')
 	{
 	  $return .= '
 				<OPTION VALUE="'.db_result($result,$i,0).'"';
@@ -426,9 +426,9 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
 				Determine if it's checked
 	  */
 	  $val=db_result($result,$i,0);
-	  for ($j=0; $j<$checked_count; $j++) 
+	  for ($j=0; $j<$checked_count; $j++)
 	    {
-	      if ($val == $checked_array[$j]) 
+	      if ($val == $checked_array[$j])
 		{
 		  $return .= ' SELECTED';
 		}
@@ -446,22 +446,22 @@ function html_select_permission_box ($artifact, $row, $level="member")
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_select_permission_box ($artifact, $row, $level="member")';
   // If $row['user_id'] does not exists, we havent got a row but simple value
-  // and it means that we are about to modify per group default 
+  // and it means that we are about to modify per group default
   if ($level == "type")
     {
       $value = $row;
       $default = 0;
     }
   elseif ($level == "group")
-    { 
+    {
       $value = $row;
       $default = _("Group Type Default");
     }
   else
-    {       
+    {
       $num = $row['user_id'];
       $value = $row[$artifact.'_flags'];
-      $default = _("Group Default"); 
+      $default = _("Group Default");
     }
 
   print '
@@ -477,23 +477,23 @@ function html_select_permission_box ($artifact, $row, $level="member")
   if ($artifact != "news")
     {
       print '
-        <option value="1"'.(($value == 1)?" selected":"").'>'._("Technician").'</option>';   
+        <option value="1"'.(($value == 1)?" selected":"").'>'._("Technician").'</option>';
     }
-  
+
   print '
         <option value="3"'.(($value == 3)?" selected":"").'>'._("Manager").'</option>';
-   
-   
+
+
   if ($artifact != "news")
     {
       print '
         <option value="2"'.(($value == 2)?" selected":"").'>'._("Techn. & Manager").'</option>';
     }
-  
+
   print '
       </select>';
 
-  if (!$value && $level == "group") 
+  if (!$value && $level == "group")
     {
       $value = group_gettypepermissions($GLOBALS[group_id], $artifact);
       print '<br>('.
@@ -501,7 +501,7 @@ function html_select_permission_box ($artifact, $row, $level="member")
 	(($value == 1)?_("Technician"):"").
 	(($value == 3)?_("Manager"):"").
 	(($value == 2)?_("Techn. & Manager"):"").
-	')'; 
+	')';
     }
   print '
     </td>';
@@ -521,7 +521,7 @@ function html_select_typedir_box ($input_name, $current_value)
         <option value="cvsattic"'.(($current_value == "cvsattic")?" selected":"").'>'._("Cvs Attic").'</option>
       </select> [BACKEND SPECIFIC]
 ';
-  
+
   // put some information
   print '<br><font class="italic">Basic directory will make the backend using DownloadMakeArea(), defined in Savannah::Download; <br> CVS directory will make the backend using CvsMakeArea(), defined in Savannah::Cvs;<br>
 (If you need to build directories with another method, the solution is to write a new sub in the appropriate perl module, please send a mail to savannah-dev@gnu.org to get information about that)</font><br>';
@@ -553,7 +553,7 @@ function html_select_theme_box ($input_name="user_theme", $current=0)
 	{ print ' ('._("default").')'; }
       print '</option>'."\n";
     }
- 
+
   // special rotate case
   $theme = "rotate";
   print "\n\t\t".'<option value="'.$theme.'"';
@@ -570,7 +570,7 @@ function html_select_theme_box ($input_name="user_theme", $current=0)
 
 }
 
-function html_build_priority_select_box ($name='priority', $checked_val='5') 
+function html_build_priority_select_box ($name='priority', $checked_val='5')
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_priority_select_box ';
   /*
@@ -579,48 +579,48 @@ function html_build_priority_select_box ($name='priority', $checked_val='5')
   */
     ?>
      <SELECT NAME="<?php print $name; ?>">
-	<OPTION VALUE="1"<?php if ($checked_val=="1") 
+	<OPTION VALUE="1"<?php if ($checked_val=="1")
 	  {print " SELECTED";} ?>>1 - Lowest</OPTION>
-				    <OPTION VALUE="2"<?php if ($checked_val=="2") 
+				    <OPTION VALUE="2"<?php if ($checked_val=="2")
 				      {print " SELECTED";} ?>>2</OPTION>
-								<OPTION VALUE="3"<?php if ($checked_val=="3") 
+								<OPTION VALUE="3"<?php if ($checked_val=="3")
 								  {print " SELECTED";} ?>>3</OPTION>
-											    <OPTION VALUE="4"<?php if ($checked_val=="4") 
+											    <OPTION VALUE="4"<?php if ($checked_val=="4")
 											      {print " SELECTED";} ?>>4</OPTION>
-															<OPTION VALUE="5"<?php if ($checked_val=="5") 
+															<OPTION VALUE="5"<?php if ($checked_val=="5")
 															  {print " SELECTED";} ?>>5 - Medium</OPTION>
-																		    <OPTION VALUE="6"<?php if ($checked_val=="6") 
+																		    <OPTION VALUE="6"<?php if ($checked_val=="6")
 																		      {print " SELECTED";} ?>>6</OPTION>
-																						<OPTION VALUE="7"<?php if ($checked_val=="7") 
+																						<OPTION VALUE="7"<?php if ($checked_val=="7")
 																						  {print " SELECTED";} ?>>7</OPTION>
-																									    <OPTION VALUE="8"<?php if ($checked_val=="8") 
+																									    <OPTION VALUE="8"<?php if ($checked_val=="8")
 																									      {print " SELECTED";} ?>>8</OPTION>
-																													<OPTION VALUE="9"<?php if ($checked_val=="9") 
+																													<OPTION VALUE="9"<?php if ($checked_val=="9")
 																													  {print " SELECTED";} ?>>9 - Highest</OPTION>
 																																    </SELECT>
 																																    <?php
 
 																																    }
-function html_buildpriority_select_box ($name='priority', $checked_val='5') 
+function html_buildpriority_select_box ($name='priority', $checked_val='5')
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_buildpriority_select_box  ';
   return html_build_priority_select_box($name, $checked_val);
 }
 
 
-function html_build_checkboxarray($options,$name,$checked_array) 
+function html_build_checkboxarray($options,$name,$checked_array)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_checkboxarray ';
   $option_count=count($options);
   $checked_count=count($checked_array);
 
-  for ($i=1; $i<=$option_count; $i++) 
+  for ($i=1; $i<=$option_count; $i++)
     {
       print '
 			<BR><INPUT type="checkbox" name="'.$name.'" value="'.$i.'"';
-      for ($j=0; $j<$checked_count; $j++) 
+      for ($j=0; $j<$checked_count; $j++)
 	{
-	  if ($i == $checked_array[$j]) 
+	  if ($i == $checked_array[$j])
 	    {
 	      print ' CHECKED';
 	    }
@@ -629,7 +629,7 @@ function html_build_checkboxarray($options,$name,$checked_array)
     }
 }
 
-function html_buildcheckboxarray($options,$name,$checked_array) 
+function html_buildcheckboxarray($options,$name,$checked_array)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_buildcheckboxarray ';
   //deprecated
@@ -640,7 +640,7 @@ function html_build_checkbox ($name, $is_checked=0)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_checkbox ($name, $is_checked=0)';
   print  '<input type="checkbox" name="'.$name.'" value="1"';
-  if ($is_checked) 
+  if ($is_checked)
     { print ' checked'; }
   print '>';
 }
@@ -651,16 +651,16 @@ function html_build_checkbox ($name, $is_checked=0)
         @param params array() must contain $user_id
         @result text - prints HTML to the screen directly
 */
-function site_header($params) 
+function site_header($params)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_header($params) ';                                                        
+  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_header($params) ';
   global $HTML;
   print $HTML->header($params);
   print html_feedback_top($GLOBALS['feedback']);
   print $HTML->site_tabs($params);
 }
 
-function site_footer($params) 
+function site_footer($params)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_footer($params) ';
   global $HTML;
@@ -679,7 +679,7 @@ function site_footer($params)
 	@param params array() must contain $toptab and $group
 	@result text - prints HTML to the screen directly
 */
-function site_project_header($params) 
+function site_project_header($params)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_project_header($params) ';
   global $HTML;
@@ -692,24 +692,24 @@ function site_project_header($params)
 
   $group_id=$params['group'];
 
-  //get the project object 
+  //get the project object
   $project=project_get_object($group_id);
 
   //group doesn't exist
-  if ($project->isError()) 
+  if ($project->isError())
     {
       exit_error("Invalid Group $group_id","That group does not exist.");
     }
 
   //group is private
-  if (!$project->isPublic()) 
+  if (!$project->isPublic())
     {
       //if its a private group, you must be a member of that group
       session_require(array('group'=>$group_id));
     }
 
   //for dead projects must be member of admin project
-  if (!$project->isActive()) 
+  if (!$project->isActive())
     {
       // only sys_group people can view non-active, non-holding groups
       session_require(array('group'=>$GLOBALS['sys_group_id']));
@@ -721,12 +721,12 @@ function site_project_header($params)
 }
 
 /*!     @function site_project_footer
-	@abstract currently a simple shim that should be on every project page, 
+	@abstract currently a simple shim that should be on every project page,
 		rather than a direct call to site_footer() or theme_footer()
 	@param params array() empty
 	@result text - prints HTML to the screen directly
 */
-function site_project_footer($params) 
+function site_project_footer($params)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_project_footer($params) ';
   global $HTML;
@@ -740,12 +740,12 @@ function site_project_footer($params)
 */
 
 /*!     @function site_user_header
-	@abstract everything required to handle security and 
+	@abstract everything required to handle security and
 		add navigation for user pages like /my/ and /account/
 	@param params array() must contain $user_id
 	@result text - prints HTML to the screen directly
 */
-function site_user_header($params) 
+function site_user_header($params)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_user_header($params) ';
   global $HTML;
@@ -760,28 +760,28 @@ function site_user_header($params)
   print $HTML->header($params);
   print html_feedback_top($GLOBALS['feedback']);
   print $HTML->user_tabs($params);
-}       
+}
 
 /*!     @function site_user_footer
-	@abstract currently a simple shim that should be on every user page, 
+	@abstract currently a simple shim that should be on every user page,
 		rather than a direct call to site_footer() or theme_footer()
 	@param params array() empty
 	@result text - prints HTML to the screen directly
 */
-function site_user_footer($params) 
+function site_user_footer($params)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_user_footer($params) ';
   global $HTML;
   html_feedback_bottom($GLOBALS['feedback']);
   print $HTML->footer($params);
-}       
+}
 
 /*
 	Administrative pages functions
 	----------------------------------------------------------------
 */
 
-function site_admin_header($params) 
+function site_admin_header($params)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_admin_header($params) ';
   global $HTML,$feedback;
@@ -793,7 +793,7 @@ function site_admin_header($params)
   $HTML->admin_tabs($params);
 }
 
-function site_admin_footer($params) 
+function site_admin_footer($params)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_admin_footer($params) ';
   global $HTML,$feedback;
@@ -801,7 +801,7 @@ function site_admin_footer($params)
   $HTML->footer($params);
 }
 
-function show_group_type_box($name='group_type',$checked_val='xzxz') 
+function show_group_type_box($name='group_type',$checked_val='xzxz')
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_group_type_box ';
   $result=db_query("SELECT * FROM group_type");
@@ -812,13 +812,13 @@ function show_group_type_box($name='group_type',$checked_val='xzxz')
 function html_member_explain_roles ()
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_member_explain_roles ';
-  
-  print _("Technicians, and only technicians, can be assigned trackers's items. They cannot reassign items, change the status or priority of items.");
+
+  print _("Technicians, and only technicians, can be assigned tracker's items. They cannot reassign items, change the status or priority of items.");
   print '<p>';
   print _("Trackers Managers can fully manage the trackers items, including assigning items to technicians, reassign items over trackers and projects, changing priority and status of items - but they cannot configure the trackers.");
   print '<p>';
-  print _("Project Admins can manage members, configure the trackers, post jobs, add mailing-list. They actually also have both technician and manager rights on vevery trackers.");
+  print _("Project Admins can manage members, configure the trackers, post jobs, and add mailing-list. They actually also have both technician and manager rights on every tracker.");
   print '<p>';
 }
 
-?>
\ No newline at end of file
+?>
