@@ -1,48 +1,48 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: sendmail.php,v 1.8 2004/02/02 15:26:29 yeupou Exp $
-//
-//  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-// 
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: sendmail.php,v 1.9 2004/02/12 16:34:08 yeupou Exp $
+#
+#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+# 
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-// Every mails sent should be using functions listed here.
+# Every mails sent should be using functions listed here.
 
-// The function that finally send the mail.
-// Every mail sent by Savannah should be using that function which
-// works like mail().
-// Note: $to can be a coma-separated list.
+# The function that finally send the mail.
+# Every mail sent by Savannah should be using that function which
+# works like mail().
+# Note: $to can be a coma-separated list.
 function sendmail_mail ($from, $to, $subject, $message, $savannah_project=0, $savannah_artifact=0, $savannah_artifact_id=0, $reply_to=0, $additional_headers=0) 
 {
 	
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':sendmail_mail  ';
 
-  // Make sure that users cannot insert malicious content
+  # Make sure that users cannot insert malicious content
   $to = stripslashes($to);
   $from = stripslashes($from);
   $subject = stripslashes($subject);
   $message = stripslashes($message);
 
-  // Transform $to in an ordered list, without duplicates
-  // (remove blankspaces)
+  # Transform $to in an ordered list, without duplicates
+  # (remove blankspaces)
   $xcopy = $to;
   $to = array_unique(explode(",", ereg_replace(" ", "", $to)));
 
-  // Write the add. headers 
+  # Write the add. headers 
   $more_headers = "From: ".$from."\n";
   if ($reply_to)
     { $more_headers .= "Reply-To: ".$reply_to."\n"; }
@@ -57,25 +57,25 @@ function sendmail_mail ($from, $to, $subject, $message, $savannah_project=0, $sa
     { $more_headers .= $additional_headers."\n";  }
   $more_headers .= "User-Agent: ".$GLOBALS['HTTP_USER_AGENT']."\n";
   $more_headers .= "X-Apparently-From: ".$GLOBALS['REMOTE_ADDR']."\n";
-  $more_headers .= "X-Copy-To: ".$xcopy; // persons in Cc, [bugs #6821]
+  $more_headers .= "X-Copy-To: ".$xcopy; # persons in Cc, [bugs #6821]
   
-  // Add eventually info on the subject
+  # Add eventually info on the subject
   if ($savannah_artifact && $savannah_artifact_id) 
     { $subject = "[".$savannah_artifact." #".$savannah_artifact_id."] ".$subject; }
     
-  // Add a signature for the server
+  # Add a signature for the server
   $message .= "\n\n_______________________________________________
   ".sprintf(_("Message sent via/by %s"), $GLOBALS['sys_name'])."
   http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home']."\n";
 
-  // Send it
+  # Send it
   while (list($k,$v) = each($to)) 
     {
       
-      // If an address is a username (no @), get the email address from
-      // the database.
-      // If nothing is found, just let the username (there's maybe a 
-      // local alias).
+      # If an address is a username (no @), get the email address from
+      # the database.
+      # If nothing is found, just let the username (there's maybe a 
+      # local alias).
       if (!ereg("@", $v)) 
 	{
 	  if (user_exists($v)) 
@@ -84,11 +84,11 @@ function sendmail_mail ($from, $to, $subject, $message, $savannah_project=0, $sa
 	    }
 	}
       
-      // Send the mail
+      # Send the mail
       if ($v) 
 	{
 	  $ret .= mail($v, $subject, $message, $more_headers);
-	  fb(sprintf(_("Mail sent to %s"), $v), 0);
+	  fb(sprintf(_("Mail sent to %s"), utils_antispam_email($v)));
 	} 
       else 
 	{
@@ -100,7 +100,7 @@ function sendmail_mail ($from, $to, $subject, $message, $savannah_project=0, $sa
 }
 
 
-// A form for logged in users to send mails to others users
+# A form for logged in users to send mails to others users
 function sendmail_form_message ($form_action, $user_id) 
 {
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':sendmail_form_message ($form_action, $user_id) ';  global $HTML;
