@@ -1,36 +1,29 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: session.php,v 1.18 2004/01/31 00:56:18 yeupou Exp $
-//
-//
-// 
-// Copyright 1999-2000 (c) The SourceForge Crew
-//
-//
-//  Copyright 2000-2003 (c) Free Software Foundation,
-//                          Mathieu Roy <yeupou@gnu.org>
-//                          Derek Feichtinger <derek.feichtinger@cern.ch>
-// 
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: session.php,v 1.19 2004/02/15 12:40:38 yeupou Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2000-2003 (c) Free Software Foundation
+#
+#  Copyright 2003-2004 (c) Mathieu Roy <yeupou@gnu.org>
+#                          Derek Feichtinger <derek.feichtinger@cern.ch>
+# 
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
 
 $G_SESSION=array();
 $G_USER=array();
@@ -44,10 +37,10 @@ function session_login_valid($form_loginname,
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_login_valid($form_loginname,';			    
 
-  // Password is crypted if we are coming from the brother site.
-  // Normally, users should use this feature
-  // if they never login at brother site.
-  // FIXME: feel free to mess with PHP3 and crypt...
+  # Password is crypted if we are coming from the brother site.
+  # Normally, users should use this feature
+  # if they never login at brother site.
+  # FIXME: feel free to mess with PHP3 and crypt...
   global $session_hash,$feedback;
   
   if (!$form_loginname || !$form_pw) 
@@ -67,16 +60,16 @@ function session_login_valid($form_loginname,
 
 
 
-  // TODO: Brother site login mechanism should be implemented later for
-  //       all authentication methods:
-  //
+  # TODO: Brother site login mechanism should be implemented later for
+  #       all authentication methods:
+  #
 
 
-  //
-  // authentication method: PAM based
-  // this requires the 'pam_auth' php extension from
-  // http://www.math.ohio-state.edu/~ccunning/pam_auth.html
-  //
+  #
+  # authentication method: PAM based
+  # this requires the 'pam_auth' php extension from
+  # http:#www.math.ohio-state.edu/~ccunning/pam_auth.html
+  #
   if($usr['user_pw'] == 'PAM') 
     {
       $pam_error='';
@@ -89,13 +82,13 @@ function session_login_valid($form_loginname,
     } 
   else if ($usr['user_pw'] == '' && $usr['unix_pw'] == '') 
     {
-      //
-      // authentication method: Kerberos
-      // If both user_pw and unix_pw are empty the user might
-      // be able to login if she/he has a Kerberos account.
-      // Update unix_pw and user_pw.
-      // TODO: THE KERBEROS PASSWORD SHOULD NOT BE STORED LOCALLY!!!!
-      //
+      #
+      # authentication method: Kerberos
+      # If both user_pw and unix_pw are empty the user might
+      # be able to login if she/he has a Kerberos account.
+      # Update unix_pw and user_pw.
+      # TODO: THE KERBEROS PASSWORD SHOULD NOT BE STORED LOCALLY!!!!
+      #
       $ret = krb5_login($form_loginname, $form_pw);
       if($ret == KRB5_NOTOK) 
 	{
@@ -123,20 +116,20 @@ function session_login_valid($form_loginname,
     }
   else 
     {
-      // Default authentication method:
-      // MD5 encrypted password stored locally
+      # Default authentication method:
+      # MD5 encrypted password stored locally
 
-      // For this authentication method we enable a brother site
-      // login mechanism:
-      // Password is crypted (crypt()) if we are coming from the brother site.
-      // Normally, users shouldn't use this feature
-      // unless they login at brother site one time.
-      // FIXME: feel free to mess with PHP3 and crypt...
+      # For this authentication method we enable a brother site
+      # login mechanism:
+      # Password is crypted (crypt()) if we are coming from the brother site.
+      # Normally, users shouldn't use this feature
+      # unless they login at brother site one time.
+      # FIXME: feel free to mess with PHP3 and crypt...
       if ($crypted_pw) 
 	{
 	  if (crypt($usr['user_pw'],$form_pw) != $form_pw) 
 	    {
-	      //invalid password or user_name
+	      #invalid password or user_name
 	      $feedback='Invalid Password (A)';
 	      return false;
 	    }
@@ -145,7 +138,7 @@ function session_login_valid($form_loginname,
 	{
 	  if ($usr['user_pw'] != md5($form_pw)) 
 	    {
-	      //invalid password or user_name
+	      #invalid password or user_name
 	      $feedback='Invalid Password (B)';
 	      return false;
 	    }
@@ -155,39 +148,39 @@ function session_login_valid($form_loginname,
 
 
   
-  // if allowpending (for verify.php) then allow
+  # if allowpending (for verify.php) then allow
   if ($allowpending && ($usr['status'] == 'P')) 
     {
-      //1;
+      #1;
     } 
   else 
     {
       if ($usr['status'] == 'S') 
 	{ 
-	  //acount suspended
+	  #acount suspended
 	  $feedback = _('Account Suspended');
 	  return false;
 	}
       if ($usr['status'] == 'P') 
 	{ 
-	  //account pending
+	  #account pending
 	  $feedback = _('Account Pending');
 	  return false;
 	} 
       if ($usr['status'] == 'D') 
 	{ 
-	  //account deleted
+	  #account deleted
 	  $feedback = _('Account Deleted');
 	  return false;
 	}
       if ($usr['status'] != 'A') 
 	{
-	  //unacceptable account flag
+	  #unacceptable account flag
 	  $feedback = _('Account Not Active');
 	  return false;
 	}
     }
-  //create a new session
+  #create a new session
   session_set_new($usr['user_id'], $cookie_for_a_year, $stay_in_ssl);
 
   return true;
@@ -199,7 +192,7 @@ function session_checkip($oldip,$newip)
   $eoldip = explode(".",$oldip);
   $enewip = explode(".",$newip);
   
-  // ## require same class b subnet
+  # ## require same class b subnet
   if (($eoldip[0]!=$enewip[0])||($eoldip[1]!=$enewip[1])) 
     {
       return 0;
@@ -227,14 +220,14 @@ function session_cookie($n,$v,$cookie_for_a_year=0)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_cookie() ';
   
-  // Define the domain name, only the last part of it like .domain.org
-  // in order to permit any host of .domain.org to access it.
+  # Define the domain name, only the last part of it like .domain.org
+  # in order to permit any host of .domain.org to access it.
   preg_match("/[^\.\/]+\.[^\.\/]+$/", $GLOBALS['sys_default_domain'], $domain);
   $domain = ".".$domain[0];
 
   if ($cookie_for_a_year=="1") 
     {
-      // Set the cookie for a year.
+      # Set the cookie for a year.
       setcookie($n,$v, time() + 60*60*24*365 ,$GLOBALS['sys_home'],$domain,0);
     } 
   else 
@@ -351,20 +344,20 @@ function session_setglobals($user_id)
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_setglobals($user_id) ';
   global $G_USER;
   
-  //	unset($G_USER);
+  #	unset($G_USER);
   
   if ($user_id > 0) 
     {
       $result=db_query("SELECT user_id,user_name FROM user WHERE user_id='$user_id'");
       if (!$result || db_numrows($result) < 1) 
 	{
-	  //echo db_error();
+	  #echo db_error();
 	  $G_USER = array();
 	} 
       else 
 	{
 	  $G_USER = db_fetch_array($result);
-	  //			echo $G_USER['user_name'].'<BR>';
+	  #			echo $G_USER['user_name'].'<BR>';
 	}
     } 
   else 
@@ -378,24 +371,24 @@ function session_set_new($user_id, $cookie_for_a_year=0, $stay_in_ssl=1)
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_set_new($user_id, $cookie_for_a_year=0, $stay_in_ssl=1) ';
   global $G_SESSION;
   
-  //	unset($G_SESSION);
+  #	unset($G_SESSION);
   
-  // concatinate current time, and random seed for MD5 hash
-  // continue until unique hash is generated (SHOULD only be once)
+  # concatinate current time, and random seed for MD5 hash
+  # continue until unique hash is generated (SHOULD only be once)
   do {
     $pre_hash = time() . rand() . $GLOBALS['REMOTE_ADDR'] . microtime();
     $GLOBALS['session_hash'] = md5($pre_hash);
   } 
   while (db_numrows(db_query("SELECT session_hash FROM session WHERE session_hash='$GLOBALS[session_hash]'")) > 0);
   
-  // set session cookie
+  # set session cookies
   session_cookie("session_hash",$GLOBALS['session_hash'],$cookie_for_a_year);
+  session_cookie("session_uid",$user_id,$cookie_for_a_year);
   
-  // make new session entries into db
-  db_query("INSERT INTO session (session_hash, ip_addr, time, user_id, stay_in_ssl) VALUES "
-	   . "('$GLOBALS[session_hash]','$GLOBALS[REMOTE_ADDR]'," . time() . ",'$user_id','$stay_in_ssl')");
+  # make new session entries into db
+  db_query("INSERT INTO session (session_hash, ip_addr, time, user_id, stay_in_ssl) VALUES ('".addslashes($GLOBALS[session_hash])."','".addslashes($GLOBALS[REMOTE_ADDR])."'," . time() . ",'$user_id','$stay_in_ssl')");
   
-  // set global
+  # set global
   $res=db_query("SELECT * FROM session WHERE session_hash='$GLOBALS[session_hash]'");
   if (db_numrows($res) > 1) 
     {
@@ -414,27 +407,27 @@ function session_set()
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_set() ';
   global $G_SESSION,$G_USER;
   
-  //	unset($G_SESSION);
+  #	unset($G_SESSION);
   
-  // assume bad session_hash and session. If all checks work, then allow
-  // otherwise make new session
+  # assume bad session_hash and session. If all checks work, then allow
+  # otherwise make new session
   $id_is_good = 0;
   
-  // here also check for good hash, set if new session is needed
-  if ($GLOBALS['session_hash']) 
+  # here also check for good hash, set if new session is needed
+  if ($_COOKIE['session_hash'] && $_COOKIE['session_uid']) 
     {
-      $result=db_query("SELECT * FROM session WHERE session_hash='$GLOBALS[session_hash]'");
+      $result=db_query("SELECT * FROM session WHERE session_hash='".addslashes($_COOKIE[session_hash])."' AND user_id='".addslashes($_COOKIE[session_uid])."'");
       $G_SESSION = db_fetch_array($result);
     
-      // does hash exist?
+      # does hash exist?
       if ($G_SESSION['session_hash']) 
 	{
 	  if (session_checkip($G_SESSION['ip_addr'],$GLOBALS['REMOTE_ADDR'])) 
 	    {
 	      $id_is_good = 1;
 	    } 
-	} // else hash was not in database
-    } // else (hash does not exist) or (session hash is bad)
+	} # else hash was not in database
+    } # else (hash does not exist) or (session hash is bad)
   
   if ($id_is_good) 
     {
