@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: data.php,v 1.8 2004/02/03 16:47:46 yeupou Exp $
+// $Id: data.php,v 1.11 2004/03/06 16:53:35 toddy Exp $
 //
 //
 //  Copyright 1999-2000 (c) The SourceForge Crew
@@ -11,7 +11,7 @@
 //                          Mathieu Roy <yeupou--at--gnu.org>
 //
 //  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-//  
+//
 //
 //
 // Copyright (c) Xerox Corporation, CodeX Team, 2001-2002. All rights reserved
@@ -34,7 +34,7 @@
 
 /*
 
-Simple way of wrapping our SQL so it can be 
+Simple way of wrapping our SQL so it can be
 	shared among the XML outputs and the PHP web front-end
 
 	Also abstracts controls to update data
@@ -63,7 +63,7 @@ function trackers_data_get_all_fields ($group_id=false,$reload=false)
   $BF_USAGE_BY_ID=array();
   $BF_USAGE_BY_NAME=array();
 
-  // First get the all the defaults. 
+  // First get the all the defaults.
   $sql='SELECT '.ARTIFACT.'_field.bug_field_id, field_name, display_type, '.
      'display_size,label, description,scope,required,empty_ok,keep_history,special, custom, '.
      'group_id, use_it,show_on_add,show_on_add_members, place, custom_label,'.
@@ -71,7 +71,7 @@ function trackers_data_get_all_fields ($group_id=false,$reload=false)
      'FROM '.ARTIFACT.'_field, '.ARTIFACT.'_field_usage '.
      'WHERE group_id=100  '.
      'AND  '.ARTIFACT.'_field.bug_field_id='.ARTIFACT.'_field_usage.bug_field_id ';
-   
+
   $res_defaults = db_query($sql);
 
   // Now put all used fields in a global array for faster access
@@ -108,7 +108,7 @@ function trackers_data_get_all_fields ($group_id=false,$reload=false)
   //{
   //echo "<br>DBG - $key -> use_it: $val[use_it], $val[place]";
   //}
-      
+
   // rewind internal pointer of global arrays
   reset($BF_USAGE_BY_ID);
   reset($BF_USAGE_BY_NAME);
@@ -129,7 +129,7 @@ function &trackers_data_get_notification_settings($group_id, $tracker_name)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':&trackers_data_get_notification_settings($group_id, $tracker_name)';
   $result = db_query("SELECT * FROM groups WHERE group_id=$group_id");
-  if (db_numrows($result) < 1) 
+  if (db_numrows($result) < 1)
     {
       exit_no_group();
     }
@@ -266,7 +266,7 @@ function trackers_data_post_notification_settings($group_id, $tracker_name)
   } else {
     $notif_value = 1;
   }
-  
+
 //  if ($new_item_address && !validate_email($new_item_address))
 //    {
 //      $local_feedback .= _("[".$tracker_name."] notification address: ".$new_item_address." appeared Invalid");
@@ -275,7 +275,7 @@ function trackers_data_post_notification_settings($group_id, $tracker_name)
 
   // set global notification info for this group
   $res_gl=db_query("UPDATE groups SET "
-	.$tracker_name."_glnotif='$notif_value', " 
+	.$tracker_name."_glnotif='$notif_value', "
 	."send_all_".$tracker_name."='$send_all_changes', "
 	."new_".$tracker_name."_address=".($new_item_address? "'$new_item_address' " : "''")
 	. " WHERE group_id=$group_id");
@@ -301,7 +301,7 @@ function trackers_data_post_notification_settings($group_id, $tracker_name)
 	     ."email_ad='$current_email', "
 	     ."send_all_flag='$current_send_all_flag' "
 	     ." WHERE bug_fv_id=$current_fv_id");
-      if ($res_cat) { 
+      if ($res_cat) {
         $ok++;
       } else {
         $local_feedback .= _($tracker_name."_field_value table Update failed.").' '.db_error();
@@ -415,15 +415,15 @@ function trackers_data_get_all_report_fields($group_id=false,$report_id=100)
   // Build the list of fields involved in this report
   $sql = "SELECT * FROM ".ARTIFACT."_report_field WHERE report_id=$report_id";
   $res = db_query($sql);
-    
+
   while ( $arr = db_fetch_array($res) )
     {
       $field = $arr['field_name'];
       $field_id = trackers_data_get_field_id($field);
-      $BF_USAGE_BY_NAME[$field]['show_on_query'] = 
+      $BF_USAGE_BY_NAME[$field]['show_on_query'] =
 	 $BF_USAGE_BY_ID[$field_id]['show_on_query'] = $arr['show_on_query'];
 
-      $BF_USAGE_BY_NAME[$field]['show_on_result'] = 
+      $BF_USAGE_BY_NAME[$field]['show_on_result'] =
 	 $BF_USAGE_BY_ID[$field_id]['show_on_result'] = $arr['show_on_result'];
 
       $BF_USAGE_BY_NAME[$field]['place_query'] =
@@ -432,7 +432,7 @@ function trackers_data_get_all_report_fields($group_id=false,$report_id=100)
       $BF_USAGE_BY_NAME[$field]['place_result'] =
 	 $BF_USAGE_BY_ID[$field_id]['place_result'] = $arr['place_result'];
 
-      $BF_USAGE_BY_NAME[$field]['col_width'] = 
+      $BF_USAGE_BY_NAME[$field]['col_width'] =
 	 $BF_USAGE_BY_ID[$field_id]['col_width'] = $arr['col_width'];
     }
 }
@@ -459,30 +459,30 @@ function trackers_data_get_field_predefined_values ($field, $group_id=false, $ch
   else if ($field_name == 'submitted_by')
     {
       $res_value = trackers_data_get_submitters($group_id);
-    }  
+    }
   else
     {
-      
+
       // If only active field
       if ($active_only)
 	{
 	  if ($checked)
 	    {
 	      $status_cond = "AND  (status IN ('A','P') OR value_id='$checked') ";
-	    } 
+	    }
 	  else
 	    {
 	      $status_cond = "AND  status IN ('A','P') ";
 	    }
 	}
-      
+
       // CAUTION !! the fields value_id and value must be first in the
       // select statement because the output is used in the html_build_select_box
       // function
-      
+
       // yeupou@gnu.org 2003-11-24
-      // FIXME!!!!! WHAT IS THIS CRAP! 
-      // It _on purpose_ ignores the permanent values for the 
+      // FIXME!!!!! WHAT IS THIS CRAP!
+      // It _on purpose_ ignores the permanent values for the
       // system when a group have his own values.
       // And  when creating group specific values, it insert the permanent
       // system values in the group specific values.
@@ -493,7 +493,7 @@ function trackers_data_get_field_predefined_values ($field, $group_id=false, $ch
       //
       // When improving this code, please change that so it uses the permanent
       // values in any case, whatever the group specific values may be.
-      
+
       // Look for project specific values first
       $sql="SELECT value_id,value,bug_fv_id,bug_field_id,group_id,description,order_id,status ".
 	 "FROM ".ARTIFACT."_field_value ".
@@ -501,7 +501,7 @@ function trackers_data_get_field_predefined_values ($field, $group_id=false, $ch
 	 $status_cond." ORDER BY order_id ASC";
       $res_value = db_query($sql);
       $rows=db_numrows($res_value);
-      
+
       // If no specific value for this group then look for default values
       if ($rows == 0)
 	{
@@ -513,9 +513,9 @@ function trackers_data_get_field_predefined_values ($field, $group_id=false, $ch
 	  $rows=db_numrows($res_value);
 	}
     }
-  
+
   return($res_value);
-  
+
 }
 
 function trackers_data_is_custom($field, $by_field_id=false)
@@ -587,7 +587,7 @@ function trackers_data_is_showed_on_query($field)
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_is_showed_on_query($field)';
   global $BF_USAGE_BY_ID,$BF_USAGE_BY_NAME;
   return($by_field_id ? $BF_USAGE_BY_ID[$field]['show_on_query']: $BF_USAGE_BY_NAME[$field]['show_on_query']);
- 
+
 }
 
 function trackers_data_is_showed_on_result($field)
@@ -599,7 +599,7 @@ function trackers_data_is_showed_on_result($field)
 
 // return a TRUE value if non project members who still are
 // logged in users should be able to access this field
-// (first bit of show_on_add set) 
+// (first bit of show_on_add set)
 function trackers_data_is_showed_on_add($field, $by_field_id=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_is_showed_on_add($field, $by_field_id=false)';
@@ -640,7 +640,7 @@ function trackers_data_is_text_field($field, $by_field_id=false)
 function trackers_data_is_text_area($field, $by_field_id=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_is_text_area($field, $by_field_id=false)';
-  return(trackers_data_get_display_type($field, $by_field_id) == 'TA'); 
+  return(trackers_data_get_display_type($field, $by_field_id) == 'TA');
 }
 
 function trackers_data_is_select_box($field, $by_field_id=false)
@@ -667,7 +667,7 @@ function trackers_data_is_project_scope($field, $by_field_id=false)
   if ($by_field_id)
     {
       return($BF_USAGE_BY_ID[$field]['scope'] == 'P');
-    }  
+    }
   else
     {
       return($BF_USAGE_BY_NAME[$field]['scope'] == 'P');
@@ -754,7 +754,7 @@ function trackers_data_get_display_type_in_clear($field, $by_field_id=false)
   else if (trackers_data_is_text_field($field, $by_field_id))
     {
       return 'Text Field';
-    } 
+    }
   else if (trackers_data_is_text_area($field, $by_field_id))
     {
       return 'Text Area';
@@ -842,13 +842,13 @@ function trackers_data_get_default_value($field,  $by_field_id=false)
 
   $result = db_query('describe bug '.$field);
   return (db_result($result,0,'Default'));
- 
+
 }
 
 function trackers_data_get_max_value_id($field, $group_id, $by_field_id=false)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_get_max_value_id($field, $group_id, $by_field_id=false)';
- 
+
   /*
       Find the maximum value for the value_id of a field for a given group
       Return -1 if  no value exist yet
@@ -873,7 +873,7 @@ function trackers_data_get_max_value_id($field, $group_id, $by_field_id=false)
       {
 	return(db_result($res,0,'max'));
       }
-  
+
 }
 
 function trackers_data_is_value_set_empty($field, $group_id, $by_field_id=false)
@@ -881,7 +881,7 @@ function trackers_data_is_value_set_empty($field, $group_id, $by_field_id=false)
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_is_value_set_empty($field, $group_id, $by_field_id=false)';
 
   /*
-      Return true if there is an existing set of values for given field for a 
+      Return true if there is an existing set of values for given field for a
       given group and false if it is empty
   */
 
@@ -910,7 +910,7 @@ function trackers_data_copy_default_values($field, $group_id, $by_field_id=false
     {
       $field_id = trackers_data_get_field_id($field);
     }
-    
+
   // if group_id=100 (None) it is a null operation
   // because default values belong to group_id 100 by definition
   if ($group_id != 100)
@@ -925,14 +925,14 @@ function trackers_data_copy_default_values($field, $group_id, $by_field_id=false
       // Rk: The target table of the INSERT statement cannot appear in
       // the FROM clause of the SELECT part of the query because it's forbidden
       // in ANSI SQL to SELECT . So do it by hand !
-      //   
+      //
 
       $sql = "SELECT value_id,value,description,order_id,status ".
 	 "FROM ".ARTIFACT."_field_value ".
 	 "WHERE bug_field_id='$field_id' AND group_id='100'";
       $res = db_query($sql);
       $rows = db_numrows($res);
-	
+
       for ($i=0; $i<$rows; $i++)
 	{
 
@@ -953,7 +953,7 @@ function trackers_data_copy_default_values($field, $group_id, $by_field_id=false
 	    {
 	      fb(_("Insert of default value failed."), 0);
 	      db_error();
-	    } 
+	    }
 	}
     }
 }
@@ -999,7 +999,7 @@ function trackers_data_is_default_value ($item_fv_id)
 
   $sql = "SELECT bug_field_id,value_id FROM ".ARTIFACT."_field_value WHERE bug_fv_id='$item_fv_id' AND group_id='100'";
   $res = db_query($sql);
-    
+
   return ( (db_numrows($res) >= 1) ? $res : false);
 }
 
@@ -1030,7 +1030,7 @@ function trackers_data_create_value ($field, $group_id, $value, $description,$or
   if ($group_id != 100)
     {
 
-      // if the current value set for this project is empty 
+      // if the current value set for this project is empty
       // then copy the default values first (if any)
       if (trackers_data_is_value_set_empty($field,$group_id))
 	{
@@ -1044,7 +1044,7 @@ function trackers_data_create_value ($field, $group_id, $value, $description,$or
       if ($max_value_id < 0)
 	{
 	  $value_id = 200;
-	}  
+	}
       else
 	{
 	  $value_id = $max_value_id +1;
@@ -1060,9 +1060,9 @@ function trackers_data_create_value ($field, $group_id, $value, $description,$or
 	{
 	  fb(_("Insert failed."), 0);
 	  ' - '.db_error();
-        }  
+        }
       else
-	
+
 	{
 	  fb(_("New field value inserted."));
 	}
@@ -1097,7 +1097,7 @@ function trackers_data_update_value ($item_fv_id,$field,$group_id,$value,$descri
       $arr = db_fetch_array($res);
       $where_cond = 'bug_field_id='.$arr['bug_field_id'].
 	 ' AND value_id='.$arr['value_id']." AND group_id='$group_id' ";
-    } 
+    }
   else
     {
       $where_cond = "bug_fv_id='$item_fv_id' AND group_id<>'100'";
@@ -1115,7 +1115,7 @@ function trackers_data_update_value ($item_fv_id,$field,$group_id,$value,$descri
     {
       fb(_("Update of field value failed."));
       ' - '.db_error();
-    }  
+    }
   else
     {
       fb(_("New field value updated."));
@@ -1156,7 +1156,7 @@ function trackers_data_update_usage($field_name,
 
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_update_usage';
-	
+
   /*
       Update a field settings in the trackers_usage_table
       Rk: All the show_on_xxx boolean parameters are set to 0 by default because their
@@ -1167,7 +1167,7 @@ function trackers_data_update_usage($field_name,
   // if it's a required field then make sure the use_it flag is true
   if (trackers_data_is_required($field_name))
     {
-      $use_it = 1; 
+      $use_it = 1;
     }
 
   $field_id = trackers_data_get_field_id($field_name);
@@ -1200,7 +1200,7 @@ function trackers_data_update_usage($field_name,
 	 "custom_keep_history=$keep_hist ".
 	 "WHERE bug_field_id='$field_id' AND group_id='$group_id'";
       $result = db_query($sql);
-    }  
+    }
   else
     {
       $sql = 'INSERT INTO '.ARTIFACT.'_field_usage '.
@@ -1208,18 +1208,18 @@ function trackers_data_update_usage($field_name,
 	 "'$show_on_add_members','$rank',$lbl,$desc,$disp_size,$empty,$keep_hist )";
       $result = db_query($sql);
     }
-  
+
   if (db_affected_rows($result) < 1)
     {
       fb(_("Update of field usage failed."), 0);
       ' - '.db_error();
-    }  
+    }
   else
     {
-      
+
       fb(_("Field usage updated."));
     }
-  
+
 }
 
 // Get a list of technicians for a tracker
@@ -1230,9 +1230,9 @@ function trackers_data_get_technicians ($group_id)
   // But we have to handle the fact that "no setting" = get back
   // to the group, or even group type, setting.
 
-  // In fact, this is terrible, we cannot return something else than 
+  // In fact, this is terrible, we cannot return something else than
   // a mysql result if we do not want to rewrite 25 functions.
-  // So we get the appropriate list of users... and finally issue a 
+  // So we get the appropriate list of users... and finally issue a
   // mysql command only to be able to return a mysql result.
   // Please, propose something better at savannah-dev@gnu.org
 
@@ -1248,8 +1248,8 @@ function trackers_data_get_technicians ($group_id)
     {
       if (member_check($member['user_id'], $group_id, member_create_tracker_flag(ARTIFACT).'1'))
 	{
-	  if ($notfirst) 
-	    { $sql .= " OR "; } 
+	  if ($notfirst)
+	    { $sql .= " OR "; }
 	  $sql .= " user_id='".$member['user_id']."'";
 	  $notfirst = 1;
 	}
@@ -1369,15 +1369,15 @@ function trackers_data_add_history ($field_name,
 				    $old_value,
 				    $new_value,
 				    $item_id,
-				    $type=false, 
-				    $artifact=0, 
+				    $type=false,
+				    $artifact=0,
 				    $force=0)
 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_add_history ';			
+  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_add_history ';
 
   // If no artifact is defined, get the default one
-  if (!$artifact) 
+  if (!$artifact)
     {
       $artifact = ARTIFACT;
     }
@@ -1411,7 +1411,7 @@ function trackers_data_add_history ($field_name,
 	    $fld_type = ',type'; $val_type = ",'100'";
 	  }
       }
-		
+
 
   $sql="INSERT INTO ".$artifact."_history (bug_id,field_name,old_value,new_value,mod_by,date $fld_type) ".
      "VALUES ('$item_id','$field_name','$old_value','$new_value','$user','".time()."' $val_type)";
@@ -1439,7 +1439,7 @@ function trackers_data_handle_update ($group_id,
   */
 
   // Make sure  required fields are not empty
-  if (!$group_id || !$item_id || !$canned_response || 
+  if (!$group_id || !$item_id || !$canned_response ||
       (trackers_check_empty_fields($vfl) == false) )
     {
       dbg("params were group_id:$group_id item_id:$item_id canned_response:$canned_response");
@@ -1467,8 +1467,8 @@ function trackers_data_handle_update ($group_id,
   $changes = array();
   reset($vfl);
   while (list($field,$value) = each($vfl))
-    {	
-      // skip over special fields  except for summary which in this 
+    {
+      // skip over special fields  except for summary which in this
       // particular case can be processed normally
       if (trackers_data_is_special($field) && ($field != 'summary'))
 	{ continue; }
@@ -1477,19 +1477,19 @@ function trackers_data_handle_update ($group_id,
       $is_text = (trackers_data_is_text_field($field) || trackers_data_is_text_area($field));
       if  ($is_text)
 	{
-	  $differ = ($old_value != stripslashes(htmlspecialchars($value))); 
-	} 
+	  $differ = ($old_value != stripslashes(htmlspecialchars($value)));
+	}
       else if (trackers_data_is_date_field($field))
 	{
 	  // if it's a date we must convert the format to unix time
 	  list($value,$ok) = utils_date_to_unixtime($value);
 	  $differ = ($old_value != $value);
-	} 
+	}
       else
 	{
 	  $differ = ($old_value != $value);
 	}
-      
+
       if ($differ)
 	{
 	  if ($is_text)
@@ -1500,13 +1500,13 @@ function trackers_data_handle_update ($group_id,
 					$value,
 					$item_id);
 	      $value = stripslashes($value);
-	    } 
+	    }
 	  else
 	    {
 	      $upd_list .= "$field='$value',";
 	      trackers_data_add_history($field,$old_value,$value,$item_id);
 	    }
-	  
+
 	  // Keep track of the change
 	  $changes[$field]['del']=
 	     trackers_field_display($field,$group_id,$old_value,false,false,true,true);
@@ -1514,30 +1514,30 @@ function trackers_data_handle_update ($group_id,
 	     trackers_field_display($field,$group_id,$value,false,false,true,true);
 	}
     }
-  
+
   // Details field history is handled a little differently. Followup comments
   // are added in the bug history along with the comment type.
-  // 
+  //
   // If a canned response is given it overrides anything typed in the followup
-  // comment text area (aka details area). 
+  // comment text area (aka details area).
   $details = $vfl['details'];
   if ($canned_response != 100)
     {
       $sql="SELECT * FROM ".ARTIFACT."_canned_responses WHERE bug_canned_id='$canned_response'";
       $res3=db_query($sql);
-      
+
       if ($res3 && db_numrows($res3) > 0)
 	{
 	  $details = addslashes(utils_unconvert_htmlspecialchars(db_result($res3,0,'body')));
 	  fb(_("Canned response used"));
-	} 
+	}
       else
 	{
 	  fb(_("Unable to use canned response"), 0);
 	  db_error();
 	}
     }
-  
+
   // Details field history is handled a little differently. Followup comments
   // are added in the bug history along with the comment type.
   if ($details != '')
@@ -1545,7 +1545,7 @@ function trackers_data_handle_update ($group_id,
       trackers_data_add_history ('details',
 				 htmlspecialchars($details),
 				 '',
-				 $item_id, 
+				 $item_id,
 				 $vfl['comment_type_id']);
       $changes['details']['add'] = stripslashes($details);
       $changes['details']['type'] =
@@ -1571,7 +1571,7 @@ function trackers_data_handle_update ($group_id,
       if ($$dependent_on)
 	{
 	  while (list(, $dep) = each($$dependent_on))
-	    { 
+	    {
 	      trackers_data_update_dependent_items($dep, $item_id, $art);
 	      // Check if we're supposed to send all modifications to an address
 	      list($address, $sendall) = trackers_data_get_item_notification_info($dep, $art, 1);
@@ -1584,7 +1584,7 @@ function trackers_data_handle_update ($group_id,
                   $extra_addresses .= $address;
 		}
 	    }
-	}      
+	}
     }
 
   // Finally, build the full SQL query and update the bug itself (if need be)
@@ -1603,21 +1603,21 @@ function trackers_data_handle_update ($group_id,
 
   if (!$result)
     {
-      exit_error(_("Update Failed"));
+      exit_error(_("Update failed."));
       return false;
-    }  
+    }
   else
     {
       fb(_("Successfully Updated."));
       return true;
-    }  
+    }
 }
 
 function trackers_data_reassign_item ($item_id,
 				      $reassign_change_project,
 				      $reassign_change_artifact)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_reassign_item ';			
+  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_reassign_item ';
 
   global $group_id;
 
@@ -1627,14 +1627,14 @@ function trackers_data_reassign_item ($item_id,
       // If the new group_id is equal to the current one, nothing need
       // to be done, unless the artifact changed.
       // If the new group_id does not exists, nothing to be done either,
-      // unless the artifact changed: if no new valid group_id, let 
+      // unless the artifact changed: if no new valid group_id, let
       // consider that it does not require a change.
       $new_group_id = group_getid($reassign_change_project);
       if (!$new_group_id)
 	{
 	  $new_group_id = $group_id;
 	}
-      
+
 
       if ($new_group_id == $group_id && ARTIFACT == $reassign_change_artifact)
 	{
@@ -1647,17 +1647,17 @@ function trackers_data_reassign_item ($item_id,
       // To reassign an item, we close the item and we reopen a new one
       // at the appropriate place, copying information from the previous one
 
-      // Fetch all the information 
+      // Fetch all the information
       $sql = "SELECT * FROM ".ARTIFACT." WHERE bug_id='".$item_id."'";
       $res_data = db_query($sql);
       $row_data = db_fetch_array($res_data);
-      
+
       // Duplicate the report
       if (!$reassign_change_project)
 	{ $reassign_change_project = $group_id; }
-      
-      if (!$reassign_change_artifact) 
-	{ 
+
+      if (!$reassign_change_artifact)
+	{
 	  fb(_("Unable to find out to which artifact the item is to be reassigned, exiting."), 1);
 	  return 0;
 	}
@@ -1670,7 +1670,7 @@ function trackers_data_reassign_item ($item_id,
 			 $now."','".
 			 $row_data['severity']."','".
 			 $row_data['submitted_by']."','".
-			 "Reassigned item: ".addslashes($row_data['summary'])."','". 
+			 "Reassigned item: ".addslashes($row_data['summary'])."','".
 			 addslashes($row_data['details'])."','".
 			 $row_data['priority']."','".
 			 $row_data['planned_starting_date']."','".
@@ -1682,7 +1682,7 @@ function trackers_data_reassign_item ($item_id,
 	  fb(_("Unable to create a new item."), 1);
 	  return 0;
 	}
-      else 
+      else
 	{
 	  fb(_("New item created."));
 	}
@@ -1707,7 +1707,7 @@ function trackers_data_reassign_item ($item_id,
 				$reassign_change_artifact,
 				1);
 
-      if (!$new_item_id) 
+      if (!$new_item_id)
 	{
 	  fb(_("Unable to find the ID of the new item."), 1);
 	  return 0;
@@ -1716,7 +1716,7 @@ function trackers_data_reassign_item ($item_id,
       // Duplicate the comments
       $sql = "SELECT * FROM ".ARTIFACT."_history WHERE bug_id='".$item_id."' AND type='100'";
       $res_history = db_query($sql);
-      while ($row_history = db_fetch_array($res_history)) 
+      while ($row_history = db_fetch_array($res_history))
 	{
 	  $sql = "INSERT INTO ".$reassign_change_artifact."_history ".
 	     "(bug_id,field_name,old_value,mod_by,date,type) ".
@@ -1729,31 +1729,31 @@ function trackers_data_reassign_item ($item_id,
 	     $row_history['type']."')";
 
 	  $result = db_query($sql);
-	  
+
 	  if (!$result)
 	    {
 	      fb(_("Unable to duplicate a comment  from the original item report information."), 1);
 	    }
 	}
-      
+
       // Add a comment giving every original information
       $comment = "This item has been reassigned from the project ".group_getname($row_data['group_id'])." ".ARTIFACT." tracker to your tracker.\n\nThe original report is still available at ".ARTIFACT." #$item_id\n\nFollowing are the information included in the original report:\n\n";
-   
+
       $sql  = "SHOW COLUMNS FROM ".ARTIFACT;
       $res_show = db_query($sql);
       $list = array();
-      while ($row_show = db_fetch_array($res_show)) 
+      while ($row_show = db_fetch_array($res_show))
 	{
 	  // Build a list of any possible field
-	  $list[] = $row_show['Field'];   
+	  $list[] = $row_show['Field'];
 	}
 
-      while (list($l,$v) = each($list)) 
+      while (list($l,$v) = each($list))
 	{
-	  if ($row_data[$l]) 
+	  if ($row_data[$l])
 	    {
 	      $comment .= "[field #".$l."] ";
-	      $comment .= trackers_field_display($v, 
+	      $comment .= trackers_field_display($v,
 						 $group_id,
 						 $row_data[$l],
 						 false,
@@ -1775,10 +1775,10 @@ function trackers_data_reassign_item ($item_id,
 	 "'".addslashes($comment)."',".
 	 "'".user_getid()."',".
 	 "'".$now."',".
-	 "'100')";      
+	 "'100')";
 
       $result = db_query($sql);
-      
+
       if (!$result)
 	{
 	  fb(_("Unable to add a comment with the original item report information."), 0);
@@ -1787,7 +1787,7 @@ function trackers_data_reassign_item ($item_id,
       // Duplicate attachment
       $sql = "SELECT * FROM ".ARTIFACT."_file WHERE bug_id='".$item_id."'";
       $res_attachment = db_query($sql);
-      while ($row_attachment = db_fetch_array($res_attachment)) 
+      while ($row_attachment = db_fetch_array($res_attachment))
 	{
 	  $sql = "INSERT INTO ".$reassign_change_artifact."_file ".
 	     "(bug_id,submitted_by,date,description,file,filename,filesize,filetype) ".
@@ -1800,9 +1800,9 @@ function trackers_data_reassign_item ($item_id,
 	     addslashes($row_attachment['filename'])."','".
 	     addslashes($row_attachment['filesize'])."','".
 	     addslashes($row_attachment['filetype'])."')";
-	  
+
 	  $result = db_query($sql);
-	  
+
 	  if (!$result)
 	    {
 	      fb(sprintf(_("Unable to duplicate an attached file (%s) from the original item report information."), $row_attachment['filename']), 1);
@@ -1810,10 +1810,10 @@ function trackers_data_reassign_item ($item_id,
 	    }
 	}
 
-      // Duplicate CC List 
+      // Duplicate CC List
       $sql = "SELECT * FROM ".ARTIFACT."_cc WHERE bug_id='".$item_id."'";
       $res_cc = db_query($sql);
-      while ($row_cc = db_fetch_array($res_cc)) 
+      while ($row_cc = db_fetch_array($res_cc))
 	{
 	  $sql = "INSERT INTO ".$reassign_change_artifact."_cc ".
 	     "(bug_id,email,added_by,comment,date) ".
@@ -1823,30 +1823,30 @@ function trackers_data_reassign_item ($item_id,
 	     $row_cc['added_by']."','".
 	     addslashes($row_cc['comment'])."','".
 	     $row_cc['date']."')";
-	  
+
 	  $result = db_query($sql);
-	  
+
 	  if (!$result)
 	    {
-	      fb(sprintf(_("Unable to duplicate an add CC address (%s) from the original item report information."), $row_cc['email']), 1);
+	      fb(sprintf(_("Unable to duplicate a CC address (%s) from the original item report information."), $row_cc['email']), 1);
 	    }
 	}
 
-      // Close the original item 
+      // Close the original item
       $result = db_query("UPDATE ".ARTIFACT." SET status_id='3',close_date='".$now."' WHERE bug_id='".$item_id."'");
       trackers_data_add_history('close_date',$now,$now,$item_id);
-      
+
       if (!$result)
 	{
 	  fb(_("Unable to close the original item report."), 1);
 	}
-      else 
+      else
 	{
 	  fb(_("Original item is now closed."));
 	}
-      
+
     }
-  
+
 }
 
 function trackers_data_update_dependent_items ($depends_on, $item_id, $artifact)
@@ -1867,7 +1867,7 @@ function trackers_data_update_dependent_items ($depends_on, $item_id, $artifact)
 	  fb(_("Error inserting dependancy").db_error(), 0);
 	}
       else
-	{ 
+	{
 	  trackers_data_add_history("Dependencies",
 				    "-",
 				    "Depends on ".$artifact." #".$depends_on,
@@ -1890,7 +1890,7 @@ function trackers_data_create_item($group_id,$vfl)
   if (!user_isloggedin())
     {
       $user=100;
-    }  
+    }
   else
     {
       $user=user_getid();
@@ -1913,8 +1913,8 @@ function trackers_data_create_item($group_id,$vfl)
 				     "'"),
 			    0,
 			    'bug_id');
-  
-  if ($is_duplicate) 
+
+  if ($is_duplicate)
     {
       $is_duplicate = db_result(db_query("SELECT bug_id FROM ".ARTIFACT.
 					 " WHERE bug_id='".
@@ -1927,13 +1927,13 @@ function trackers_data_create_item($group_id,$vfl)
 				0,
 				'bug_id');
     }
-  
+
   if ($is_duplicate)
     {
-      $ffeedback = _(" Error - Duplicated submission. This item already exists in our database.");
-      return;		
+      $ffeedback = ' '._("Error - Duplicated submission. This item already exists in our database.");
+      return;
     }
-  
+
   // Finally, create the bug itself
   // Remark: this SQL query only sets up the values for fields used by
   // this project. For other unused fields we assume that the DB will set
@@ -1955,9 +1955,9 @@ function trackers_data_create_item($group_id,$vfl)
 	{
 	  // if it's a date we must convert the format to unix time
 	  list($value,$ok) = utils_date_to_unixtime($value);
-	} 
+	}
       $vfl_values .= ',\''.$value.'\'';
-    }    
+    }
 
 
   // Add all special fields that were not handled in the previous block
@@ -1973,7 +1973,7 @@ function trackers_data_create_item($group_id,$vfl)
 
   if (!$item_id)
     {
-      $ffeedback = _(" INSERT new bug failed.").' '._("Report to the Administrator");
+      $ffeedback = ' '._("INSERT new bug failed.").' '._("Report to the Administrator");
     }
 
   //now return the trackers_id
@@ -2017,7 +2017,7 @@ function trackers_data_get_value($field,$group_id,$value_id,$by_field_id=false)
   if ($result && db_numrows($result) > 0)
     {
       return db_result($result,0,'value');
-    } 
+    }
 
   // ... if it fails, look for system wide default values (group_id=100)...
   $sql="SELECT * FROM ".ARTIFACT."_field_value ".
@@ -2027,8 +2027,8 @@ function trackers_data_get_value($field,$group_id,$value_id,$by_field_id=false)
   if ($result && db_numrows($result) > 0)
     {
       return db_result($result,0,'value');
-    } 
-    
+    }
+
   // No value found for this value id !!!
   return $value_id.'(Error - Not Found)';
 
@@ -2050,7 +2050,7 @@ function trackers_data_get_canned_responses ($group_id)
 function trackers_data_get_reports($group_id, $user_id)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_get_reports($group_id, $user_id)';
-    
+
   // If user is unknown then get only project-wide and system wide reports
   // else get personal reports in addition  project-wide and system wide.
   $sql = 'SELECT report_id,name FROM '.ARTIFACT.'_report WHERE ';
@@ -2105,7 +2105,7 @@ function trackers_data_delete_notification($user_id)
 
 function trackers_data_insert_notification($user_id, $arr_roles, $arr_events,$arr_notification)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_insert_notification ';				
+  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_insert_notification ';
 
   $sql = 'INSERT INTO  trackers_notification (user_id,role_id,event_id,notify) VALUES ';
 
@@ -2115,27 +2115,27 @@ function trackers_data_insert_notification($user_id, $arr_roles, $arr_events,$ar
     {
       $role_id = $arr_roles[$i]['role_id'];
       for ($j=0; $j<$num_events; $j++)
-	{ 
+	{
 	  $event_id = $arr_events[$j]['event_id'];
-	  $sql .= "('$user_id','$role_id','$event_id','".$arr_notification[$role_id][$event_id]."'),"; 
-	} 
-    } 
-  $sql = substr($sql,0,-1); // remove extra comma at the end 
-  return db_query($sql); 
+	  $sql .= "('$user_id','$role_id','$event_id','".$arr_notification[$role_id][$event_id]."'),";
+	}
+    }
+  $sql = substr($sql,0,-1); // remove extra comma at the end
+  return db_query($sql);
 }
 
 function trackers_data_get_watchers($user_id)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_get_watchers($user_id)';
   $sql = "SELECT user_id,group_id FROM trackers_watcher WHERE watchee_id='$user_id'";
-  return db_query($sql);    
+  return db_query($sql);
 }
 
 function trackers_data_get_watchees($user_id)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_get_watchees($user_id)';
   $sql = "SELECT watchee_id,group_id FROM trackers_watcher WHERE user_id='$user_id'";
-  return db_query($sql);    
+  return db_query($sql);
 }
 
 function trackers_data_insert_watchees($user_id, $arr_watchees)
@@ -2147,8 +2147,8 @@ function trackers_data_insert_watchees($user_id, $arr_watchees)
   for ($i=0; $i<$num_watchees; $i++)
     {
       $sql .= "('$user_id','".$arr_watchees[$i]."'),";
-    } 
-  $sql = substr($sql,0,-1); // remove extra comma at the end 
+    }
+  $sql = substr($sql,0,-1); // remove extra comma at the end
   return db_query($sql);
 }
 
@@ -2159,7 +2159,7 @@ function trackers_data_add_watchees ($user_id, $watchee_id, $group_id)
   if (member_check(0,$group_id) && !trackers_data_is_watched($user_id,$watchee_id,$group_id))
     {
       // Only accept the request from a member of the project
-      // Note that a user can trick the URL to watch himself 
+      // Note that a user can trick the URL to watch himself
       // It has no consequences, so we do not care.
       $sql = 'INSERT INTO trackers_watcher (user_id,watchee_id,group_id) VALUES '.
 	 "('$user_id','$watchee_id','$group_id')";
@@ -2184,7 +2184,7 @@ function trackers_data_is_watched ($user_id, $watchee_id, $group_id)
 {
   $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_data_is_watched ($user_id, $watchee_id, $group_id)';
   $sql = "SELECT watchee_id FROM trackers_watcher WHERE user_id='$user_id' AND watchee_id='$watchee_id' AND group_id='$group_id'";
-  return db_result(db_query($sql),0,'watchee_id');   
+  return db_result(db_query($sql),0,'watchee_id');
 }
 
 
