@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: general.php,v 1.4 2004/02/03 15:51:09 yeupou Exp $
+// $Id: general.php,v 1.5 2004/02/12 00:28:55 toddy Exp $
 //
 // 
 // Copyright 1999-2000 (c) The SourceForge Crew
@@ -588,7 +588,7 @@ function trackers_check_empty_fields($field_array)
 
   if (count($bad_fields) > 0)
     {
-      $ffeedback = sprintf(_("Missing fields: %s. Empty values for the above listed field(s) are not allowed. Click on the Back arrow of your browser and try again"), join(', ',$bad_fields));
+      $ffeedback = sprintf(_("Missing field(s): %s. Empty values for the above listed field(s) are not allowed. Click on the \"Back\" button of your browser and try again."), join(', ',$bad_fields));
 
       return false;
     }
