@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: browse.php,v 1.23 2004/02/03 15:44:00 yeupou Exp $
+// $Id: browse.php,v 1.26 2004/03/02 18:26:18 toddy Exp $
 //
 //  Copyright 1999-2000 (c) The SourceForge Crew
 //  Copyright 2000-2003 (c) Free Software Foundation
@@ -36,11 +36,11 @@ $fields_per_line=5;
 
 // Number of bugs displayed on screen in one chunk.
 // Default 50
-if (!$chunksz) 
+if (!$chunksz)
 { $chunksz = 50; }
 
 // Make sure offset is defined and has a correct value
-if (!$offset || $offset < 0) 
+if (!$offset || $offset < 0)
 { $offset=0; }
 
 
@@ -56,31 +56,31 @@ unset($prefs['group_id']);
 /* ==================================================
    Make sure all URL arguments are captured as array. For simple
    search they'll be arrays with only one element at index 0 (this
-   will avoid to deal with scalar in simple search and array in 
+   will avoid to deal with scalar in simple search and array in
    advanced which would greatly complexifies the code)
  ================================================== */
-while (list($field,$value_id) = each($prefs)) 
+while (list($field,$value_id) = each($prefs))
 {
-  if (!is_array($value_id)) 
+  if (!is_array($value_id))
     {
       unset($prefs[$field]);
       $prefs[$field][] = $value_id;
       //echo '<br> DBG Setting $prefs['.$field.'] [] = '.$value_id;
-    } 
-  else 
+    }
+  else
     {
       //echo '<br> DBG $prefs['.$field.'] = ('.implode(',',$value_id).')';
     }
 
-  if (trackers_data_is_date_field($field)) 
+  if (trackers_data_is_date_field($field))
     {
-      if ($advsrch) 
+      if ($advsrch)
 	{
 	  $field_end = $field.'_end';
 	  $prefs[$field_end] = $$field_end;
 	  //echo '<br> DBG Setting $prefs['.$field.'_end]= '.$prefs[$field.'_end'];
-	} 
-      else 
+	}
+      else
 	{
 	  $field_op = $field.'_op';
 	  $prefs[$field_op] = $$field_op;
@@ -94,7 +94,7 @@ while (list($field,$value_id) = each($prefs))
 
 /* ==================================================
    Memorize order by field as a user preference if explicitly specified.
-   
+
    $morder = comma separated list of sort criteria followed by - for
      DESC and + for ASC order
    $order = last sort criteria selected in the UI
@@ -102,36 +102,36 @@ while (list($field,$value_id) = each($prefs))
   ================================================== */
 //echo "<br>DBG \$morder at top: [$morder ]";
 //   if morder not defined then reuse the one in preferences
-if (user_isloggedin() && !isset($morder)) 
+if (user_isloggedin() && !isset($morder))
 {
   $morder = user_get_preference('bug_browse_order'.$group_id);
 }
 
-if (isset($order)) 
+if (isset($order))
 {
 
-  if ($order != '') 
+  if ($order != '')
     {
       // Add the criteria to the list of existing ones
       $morder = trackers_add_sort_criteria($morder, $order, $msort);
-    } 
-  else 
+    }
+  else
     {
       // reset list of sort criteria
       $morder = '';
     }
 }
 
-if (isset($morder)) 
+if (isset($morder))
 {
 
-  if (user_isloggedin()) 
+  if (user_isloggedin())
     {
       if ($morder != user_get_preference('bug_browse_order'.$group_id))
 	user_set_preference('bug_browse_order'.$group_id, $morder);
     }
 
-  if ($morder != '') 
+  if ($morder != '')
     {
       $order_by = ' ORDER BY '.trackers_criteria_list_to_query($morder);
     }
@@ -145,13 +145,13 @@ if (isset($morder))
   If it is set then update the user preference.  Also initialize the
   bug report structures.
   ================================================== */
-if (user_isloggedin()) 
+if (user_isloggedin())
 {
-  if (!isset($report_id)) 
+  if (!isset($report_id))
     {
       $report_id = user_get_preference('bug_browse_report'.$group_id);
-    } 
-  else 
+    }
+  else
     {
       if ($report_id != user_get_preference('bug_browse_report'.$group_id))
 	user_set_preference('bug_browse_report'.$group_id, $report_id);
@@ -159,7 +159,7 @@ if (user_isloggedin())
 }
 
 // If still not defined then force it to system 'Default' report
-if (!$report_id) 
+if (!$report_id)
 { $report_id=100; }
 
 trackers_report_init($group_id, $report_id);
@@ -167,31 +167,31 @@ trackers_report_init($group_id, $report_id);
 
 
 /* ==================================================
-  Now see what type of bug set is requested (set is one of none, 
-  'my', 'open', 'custom'). 
+  Now see what type of bug set is requested (set is one of none,
+  'my', 'open', 'custom').
     - if no set is passed in, see if a preference was set ('custom' set).
     - if no preference and logged in then use 'my' set
     - if no preference and not logged in the use 'open' set
      (Prefs is a string of the form  &field1[]=value_id1&field2[]=value_id2&.... )
   ================================================== */
-if (!$set) 
+if (!$set)
 {
 
-  if (user_isloggedin()) 
+  if (user_isloggedin())
     {
 
       $custom_pref=user_get_preference('bug_brow_cust'.$group_id);
 
-      if ($custom_pref) 
+      if ($custom_pref)
 	{
 	  $pref_arr = explode('&',substr($custom_pref,1));
-	  while (list(,$expr) = each($pref_arr)) 
+	  while (list(,$expr) = each($pref_arr))
 	    {
 	      // Extract left and right parts of the assignment
 	      // and remove the '[]' array symbol from the left part
 	      list($field,$value_id) = explode('=',$expr);
 	      $field = str_replace('[]','',$field);
-	      if ($field == 'advsrch') 
+	      if ($field == 'advsrch')
 		$advsrch = $value_id;
 	      else if ($field == 'msort')
 		$msort = $value_id;
@@ -206,21 +206,21 @@ if (!$set)
 	    }
 	  $set='custom';
 
-	} 
-      else 
+	}
+      else
 	{
 	  $set='open';
 	}
 
     }
-  else 
+  else
     {
       $set='open';
     }
 }
 
 
-if ($set=='my') 
+if ($set=='my')
 {
   /*
       My bugs - backwards compat can be removed 9/10
@@ -228,24 +228,24 @@ if ($set=='my')
   $prefs['status_id'][]=1;
   $prefs['assigned_to'][]=user_getid();
 
-} 
-else if ($set=='custom') 
+}
+else if ($set=='custom')
 {
 
   // Get the list of bug fields used in the form (they are in the URL - GET method)
   // and then build the preferences array accordingly
   // Exclude the group_id parameter
   reset($prefs);
-  while (list($field,$arr_val) = each($prefs)) 
+  while (list($field,$arr_val) = each($prefs))
     {
-      while (list(,$value_id) = each($arr_val)) 
+      while (list(,$value_id) = each($arr_val))
 	{
 	  $pref_stg .= '&'.$field.'[]='.$value_id;
 	}
 
       // build part of the HTML title of this page for more friendly bookmarking
       // Do not add the criteria in the header if value is "Any"
-      if ($value_id != 0) 
+      if ($value_id != 0)
 	{
 	  $hdr .= ' By '.trackers_data_get_label($field).': '.
 	     trackers_data_get_value($field,$group_id,$value_id);
@@ -255,15 +255,15 @@ else if ($set=='custom')
   $pref_stg .= '&msort='.$msort;
   $pref_stg .= '&chunksz='.$chunksz;
   $pref_stg .= '&report_id='.$report_id;
-    
-  if ($pref_stg != user_get_preference('bug_brow_cust'.$group_id)) 
+
+  if ($pref_stg != user_get_preference('bug_brow_cust'.$group_id))
     {
       //echo "<br> DBG setting pref = $pref_stg";
       user_set_preference('bug_brow_cust'.$group_id,$pref_stg);
     }
 
-} 
-else 
+}
+else
 {
   // Open bugs - backwards compat can be removed 9/10
   $prefs['status_id'][]=1;
@@ -274,15 +274,15 @@ else
    as well as all the arguments that serves as selection criteria
    If not defined then defaults to ANY (0)
   ================================================== */
-if (!isset($advsrch)) 
+if (!isset($advsrch))
 { $advsrch = 0; }
-if (!isset($msort)) 
+if (!isset($msort))
 { $msort = 0; }
-while ($field = trackers_list_all_fields()) 
+while ($field = trackers_list_all_fields())
 {
   // the select boxes for the bug DB search first
   if (trackers_data_is_showed_on_query($field) &&
-      trackers_data_is_select_box($field) ) 
+      trackers_data_is_select_box($field) )
     {
       if (!isset($prefs[$field])) $prefs[$field][] = 0;
     }
@@ -298,34 +298,34 @@ $select_count = 'SELECT count(*) AS count ';
 $select = 'SELECT '.ARTIFACT.'.priority ';
 $from = 'FROM '.ARTIFACT.' ';
 $where = 'WHERE '.ARTIFACT.'.group_id='.$group_id.' ';
-if (!$pv) 
+if (!$pv)
 { $limit = " LIMIT $offset,$chunksz";}
 
 
 // prepare the where clause with the selection criteria given by the user
 reset($prefs);
-while (list($field,$value_id) = each($prefs)) 
-{ 
+while (list($field,$value_id) = each($prefs))
+{
 
-  // If the criteria is not in the field showed on query screen then 
+  // If the criteria is not in the field showed on query screen then
   // skip it. This is a sanity check to make sure that the SQL
   // query we run actually matches the displayed search criteria
-  if (!trackers_data_is_showed_on_query($field)) 
+  if (!trackers_data_is_showed_on_query($field))
     { continue; }
 
-  if (trackers_data_is_select_box($field) && !trackers_isvarany($prefs[$field]) ) 
+  if (trackers_data_is_select_box($field) && !trackers_isvarany($prefs[$field]) )
     {
 
       // Only select box criteria to where clause if argument is not ANY
       $where .= ' AND '.ARTIFACT.'.'.$field.' IN ('.implode(',',$prefs[$field]).') ';
 
-    } else if (trackers_data_is_date_field($field) && $prefs[$field][0]) 
+    } else if (trackers_data_is_date_field($field) && $prefs[$field][0])
       {
 
 	// transform a date field into a unix time and use <, > or =
 	list($time,$ok) = utils_date_to_unixtime($prefs[$field][0]);
 
-	if ($advsrch) 
+	if ($advsrch)
 	  {
 	    list($time_end,$ok_end) = utils_date_to_unixtime($prefs[$field.'_end'][0]);
 	    if ($ok)
@@ -335,18 +335,18 @@ while (list($field,$value_id) = each($prefs))
 	      $where .= ' AND '.ARTIFACT.'.'.$field.' <= '. $time_end;
 
 
-	  } 
-	else 
+	  }
+	else
 	  {
 
 	    $operator = $prefs[$field.'_op'][0];
 	    // '=' means that day between 00:00 and 23:59
-	    if ($operator == '=') 
+	    if ($operator == '=')
 	      {
 		$time_end = mktime(23, 59, 59, $month, $day, $year);
 		$where .= ' AND '.ARTIFACT.'.'.$field." >= $time ".'AND '.ARTIFACT.'.'.$field." <= $time_end ";
-	      } 
-	    else 
+	      }
+	    else
 	      {
 		$where .= ' AND '.ARTIFACT.'.'.$field." $operator= $time ";
 	      }
@@ -356,7 +356,7 @@ while (list($field,$value_id) = each($prefs))
 	$where .= ' AND '.ARTIFACT.'.'.$field." <> 0 ";
 
       } else if ((trackers_data_is_text_field($field) || trackers_data_is_text_area($field))
-		 && $prefs[$field][0]) 
+		 && $prefs[$field][0])
 	{
 
 	  // It's a text field accept. Process INT or TEXT,VARCHAR fields differently
@@ -370,17 +370,17 @@ while (list($field,$value_id) = each($prefs))
   ================================================== */
 $ib=0;$is=0;
 $load_cal=false;
-while ( $field = trackers_list_all_fields(cmp_place_query)) 
+while ( $field = trackers_list_all_fields(cmp_place_query))
 {
 
-  if (!trackers_data_is_used($field) || 
-      !trackers_data_is_showed_on_query($field) ) 
-    { 
+  if (!trackers_data_is_used($field) ||
+      !trackers_data_is_showed_on_query($field) )
+    {
       continue;
     }
 
   // beginning of a new row
-  if ($ib % $fields_per_line == 0) 
+  if ($ib % $fields_per_line == 0)
     {
       $align = ($pv ? "left" : "center");
       $labels .= "\n".'<tr align="'.$align.'" valign="top">';
@@ -396,10 +396,10 @@ while ( $field = trackers_list_all_fields(cmp_place_query))
 
   $boxes .= '<TD><FONT SIZE="-1">';
 
-  if (trackers_data_is_select_box($field) ) 
+  if (trackers_data_is_select_box($field) )
     {
 
-      $boxes .= 
+      $boxes .=
 	 trackers_field_display($field,$group_id,
 				($advsrch ? $prefs[$field] : $prefs[$field][0]),
 				false,false,($pv?true:false),false,true,'None', true,'Any');
@@ -407,18 +407,18 @@ while ( $field = trackers_list_all_fields(cmp_place_query))
     } else if (trackers_data_is_date_field($field) ){
 
       $load_cal = true; // We need to load the Javascript Calendar
-      if ($advsrch) 
+      if ($advsrch)
 	$boxes .= trackers_multiple_field_date($field,$prefs[$field][0],
 					       $prefs[$field.'_end'][0],0,0,$pv);
       else
 	$boxes .= trackers_field_date_operator($field,$prefs[$field.'_op'][0],$pv).
 	  trackers_field_date($field,$prefs[$field][0],0,0,$pv);
-		
-    } else if (trackers_data_is_text_field($field) || 
-	       trackers_data_is_text_area($field) ) 
+
+    } else if (trackers_data_is_text_field($field) ||
+	       trackers_data_is_text_area($field) )
       {
 
-	$boxes .= 
+	$boxes .=
 	   ($pv ? $prefs[$field][0] : trackers_field_text($field,$prefs[$field][0],15,80)) ;
 
       }
@@ -427,7 +427,7 @@ while ( $field = trackers_list_all_fields(cmp_place_query))
   $ib++;
 
   // end of this row
-  if ($ib % $fields_per_line == 0) 
+  if ($ib % $fields_per_line == 0)
     {
       $html_select .= $labels.'</TR>'.$boxes.'</TR>';
       $labels = $boxes = '';
@@ -436,43 +436,43 @@ while ( $field = trackers_list_all_fields(cmp_place_query))
 }
 
 // Make sure the last few cells are in the table
-if ($labels) 
+if ($labels)
 {
   $html_select .= $labels.'</TR>'.$boxes.'</TR>';
 }
 
 
 /* ==================================================
-   Loop through the list of used fields to see what fields are in the 
+   Loop through the list of used fields to see what fields are in the
    result table and complement the SQL query accordingly.
   ================================================== */
-while ( $field = trackers_list_all_fields(cmp_place_result)) 
+while ( $field = trackers_list_all_fields(cmp_place_result))
 {
 
-  if (!trackers_data_is_used($field) || 
-      !trackers_data_is_showed_on_result($field) ) 
-    { 
+  if (!trackers_data_is_used($field) ||
+      !trackers_data_is_showed_on_result($field) )
+    {
       continue;
     }
 
   $col_list[] = $field;
   $width_list[] = trackers_data_get_col_width($field);
   $lbl_list[] = trackers_data_get_label($field);
-    
-  if ( trackers_data_is_username_field($field)) 
+
+  if ( trackers_data_is_username_field($field))
     {
       // user names requires some special processing to display the username
       // instead of the user_id
       $select .= ",user_$field.user_name AS $field";
       $from .= ",user user_$field";
       $where .= " AND user_$field.user_id=".ARTIFACT.".$field ";
-    } 
-  else 
+    }
+  else
     {
       // otherwise just select this column as is
       $select .= ",".ARTIFACT.".$field";
     }
-    
+
 }
 
 /* ==================================================
@@ -497,16 +497,16 @@ $result=db_query($sql);
    Display the HTML search form
   ================================================== */
 
-if ($pv) 
+if ($pv)
 {
   help_header(_("Bug Search Report").' - '.format_date($sys_datefmt,time()),false);
-} 
-else 
+}
+else
 {
   trackers_header(array('title'=>_("Browse").' '.$hdr));
 }
 
-if ($load_cal) 
+if ($load_cal)
 {
   echo ' <script language="JavaScript" src="'.
     $GLOBALS['sys_home'].'include/calendar.js"></script> ';
@@ -516,15 +516,15 @@ echo '    <FORM ACTION="'.$PHP_SELF .'" METHOD="GET" NAME="bug_form">
           <INPUT TYPE="HIDDEN" NAME="group_id" VALUE="'.$group_id.'">
           <INPUT TYPE="HIDDEN" NAME="set" VALUE="custom">
           <INPUT TYPE="HIDDEN" NAME="msort" VALUE="'.$msort.'">
-          <h3>'._("Browse");
+          <h3>'._("Browse").' ';
 
 // Show the list of available bug reports kind
-if (!$pv) 
+if (!$pv)
 {
   $res_report = trackers_data_get_reports($group_id,user_getid());
   $box_name = 'report_id" onChange="document.bug_form.go_report.click()';
 
-  printf(_(" with the %s query form"), html_build_select_box($res_report,$box_name,$report_id,true,'Basic'));
+  printf(_("with the %s query form"), html_build_select_box($res_report,$box_name,$report_id,true,'Basic'));
 }
 
 // Start building the URL that we use to for hyperlink in the form
@@ -538,33 +538,33 @@ $url_nomorder = $url;
 $url .= "&morder=$morder";
 
 // Build the URL for alternate Search
-if ($advsrch) 
-{ 
+if ($advsrch)
+{
   $url_alternate_search = str_replace('advsrch=1','advsrch=0',$url);
   $text = _("Simple Search");
-} 
-else 
-{    
-  $url_alternate_search = str_replace('advsrch=0','advsrch=1',$url); 
+}
+else
+{
+  $url_alternate_search = str_replace('advsrch=0','advsrch=1',$url);
   $text = _("Advanced Search");
 }
 
 // Select 'list form' or 'select' form
-if (!$pv) 
+if (!$pv)
 {
-  if ($advsrch) 
+  if ($advsrch)
     {
       $advsrch_1 = ' selected';
-    } 
-  else 
+    }
+  else
     {
       $advsrch_0 = ' selected';
     }
-  printf(_(" and %s selection"), '<select name="advsrch"><option value="0"'.$advsrch_0.'>'._("Simple").'</option><option value="1"'.$advsrch_1.'>'._("Multiple").'</option></select>');
+  printf(' '._("and %s selection."), '<select name="advsrch"><option value="0"'.$advsrch_0.'>'._("Simple").'</option><option value="1"'.$advsrch_1.'>'._("Multiple").'</option></select>');
 }
 
 // End the form type selection
-echo '. <input value="'._("Apply").'" name="go_report" type="submit">';
+echo '<input value="'._("Apply").'" name="go_report" type="submit">';
 echo '</h3>';
 
 echo '<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="5">
@@ -573,7 +573,7 @@ echo '<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="5">
 echo $html_select;
 
 echo '</table>';
-if (!$pv) 
+if (!$pv)
 {
   echo '<p><font class="smaller">Show</font> '.
     '<input type="text" name="chunksz" size="3" maxlength="5" '.
@@ -586,53 +586,55 @@ if (!$pv)
 
 $numrows = db_numrows($result);
 
-if ($result && $numrows > 0) 
+if ($result && $numrows > 0)
 {
 
   // Build the sorting header messages
-  if ($morder) 
+  if ($morder)
     {
       $order_statement = _("sorted by:")." ".trackers_criteria_list_to_text($morder, $url_nomorder);
-    } 
-  else 
+    }
+  else
     {
       $order_statement ='';
     }
   echo '<a name="results"></a>';
-  // remove plural management to make i18n easier 
-  echo '<h3>'.$totalrows.' '._("matching item").' '.$order_statement.'</h3>';
+  # add the plural in brackets, so it looks a little nicer -- toddy 2004-02-29
+  echo '<h3>'.$totalrows.' '._("matching item(s)").' '.$order_statement.'</h3>';
 
 
-  if ($msort) 
-    { 
-      $url_alternate_sort = str_replace('msort=1','msort=0',$url).'&order=#results';
-      $text = _("deactivate");
-    } 
-  else 
-    {    
-      $url_alternate_sort = str_replace('msort=0','msort=1',$url).'&order=#results';
-      $text = _("activate");
-    }
-  if (!$pv) 
+  if (!$pv)
     {
-      echo '<p>'._("Click a column heading to sort results (up or down)").', '.
-	_("or").' <a href="'.$url.'&amp;order=priority#results"><b>'._("sort by priority").'</b></a> '.
-	_("or").' <a href="'.$url.'&order=#results"><b>'._("reset sort").'</b></a>. ';
-      echo _("You can also").' <a href="'.$url_alternate_sort.'"><b> '.$text.' ';
-      echo _("multicolumn sort").'</b></a>.&nbsp;&nbsp;&nbsp;&nbsp;'.
-	'(<a href="'.$url.'&pv=1"> <img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/print.png" border="0">';
-      echo '&nbsp;'._("Printer version").'</a>)'."\n";
-    } 
-  else 
-    { 
-      $chunksz = 100000; 
+    echo '<p>';
+    if ($msort)
+      {
+        $url_alternate_sort = str_replace('msort=1','msort=0',$url).'&order=#results';
+        printf(_("Click a column heading to sort results (up or down), or %ssort by priority%s or %sreset sort%s. You can also %sdeactivate%s multicolumn sort."),
+          '<a href="'.$url.'&amp;order=priority#results"><b>', '</b></a>',
+          '<a href="'.$url.'&order=#results"><b>', '</b></a>',
+          '<a href="'.$url_alternate_sort.'"><b>', '</b></a>');
+      }
+    else
+      {
+        $url_alternate_sort = str_replace('msort=0','msort=1',$url).'&order=#results';
+        printf(_("Click a column heading to sort results (up or down), or %ssort by priority%s or %sreset sort%s. You can also %sactivate%s multicolumn sort."),
+          '<a href="'.$url.'&amp;order=priority#results"><b>', '</b></a>',
+          '<a href="'.$url.'&order=#results"><b>', '</b></a>',
+          '<a href="'.$url_alternate_sort.'"><b>', '</b></a>');
+      }
+      echo '&nbsp;&nbsp;&nbsp;&nbsp;(<a href="'.$url.'&pv=1"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/print.png" border="0">';
+      echo '&nbsp;'._("Printer version").'</a>)</p>'."\n";
+    }
+  else
+    {
+      $chunksz = 100000;
     }
   show_item_list($result,$offset,$totalrows,$col_list,$lbl_list,$width_list,
 	       ($pv ? '' : $url), ($pv ? true:false) );
   show_priority_colors_key('Severity colors:');
 
-} 
-else 
+}
+else
 {
 
   echo '<h2>'._("No Matching Items Found for").' '.group_getname($group_id).' '._("or filters too restrictive").'</h2>';
