@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: detail.php,v 1.23 2004/01/31 00:56:19 yeupou Exp $
+// $Id: detail.php,v 1.24 2004/02/12 20:43:44 toddy Exp $
 //
 //
 // Copyright 1999-2000 (c) The SourceForge Crew
@@ -149,7 +149,8 @@ if (db_numrows($result) > 0)
   print '<font class="preinput"> '._("Attach File:").'</font><br>
       &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="60">
       <br>
-      <font class="preinput">'._("File Description:").'</font><br>
+      <font class="preinput">'
+      ._("File Description:").'</font><br>
       &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255">
       </p><p>';
 
