@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: mod.php,v 1.3 2004/01/31 00:56:19 yeupou Exp $
+// $Id: mod.php,v 1.5 2004/02/24 14:22:32 toddy Exp $
 //
 //
 // Copyright 1999-2000 (c) The SourceForge Crew
@@ -279,8 +279,8 @@ if (db_numrows($result) > 0)
     }
       
   print '<font class="preinput">'._("Of:").'</font><br>
-&nbsp;&nbsp;&nbsp;<select name="depends_search_only_artifact">
-<option value="all">'._("Any Trackers").'</option>';
+&nbsp;&nbsp;&nbsp;<select name="depends_search_only_artifact">'
+.'<option value="all">'._("any Trackers").'</option>';
 
   specific_depends_on_artifact("support", _("the Support Tracker Only"));
   specific_depends_on_artifact("bugs", _("the Bug Tracker Only"));
@@ -289,9 +289,9 @@ if (db_numrows($result) > 0)
 
   print '</select> ';
   print _("of");
-  print ' <select name="depends_search_only_project">
-   <option value="any">'._("Any Project").'</option>
-   <option value="notany" selected>'._("this Project Only").'</option>
+  print ' <select name="depends_search_only_project">'
+   .'<option value="any">'._("any Project").'</option>'
+   .'<option value="notany" selected>'._("this Project Only").'</option>
    </select>&nbsp;';
 
   if (!$depends_search) 
@@ -302,7 +302,7 @@ if (db_numrows($result) > 0)
     { 
       // Print a specific message if we are already at step 2 of filling
       // a dependency.
-      print '<input type="submit" name="submit" class="bold" value="'._("New Search").'">';
+      print '<input type="submit" name="submit" class="bold" value="'._("New search").'">';
     }
 
   // Search results, if we are already at step 2 of filling
@@ -419,7 +419,7 @@ if (db_numrows($result) > 0)
 	{ 
 	  // Print a specific message if we are already at step 2 of filling
 	  // a ressign.
-	  print ' <input type="submit" name="submit" class="bold" value="'._("New Search").'">';
+	  print ' <input type="submit" name="submit" class="bold" value="'._("New search").'">';
 	}
       
 
