@@ -2,16 +2,16 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: reporting.php,v 1.13 2004/01/31 00:56:19 yeupou Exp $
+// $Id: reporting.php,v 1.14 2004/03/02 18:26:18 toddy Exp $
 //
 //
 // CodeX: Breaking Down the Barriers to Source Code Sharing inside Xerox
-// Copyright (c) Xerox Corporation, CodeX / CodeX Team, 2001-2002. 
+// Copyright (c) Xerox Corporation, CodeX / CodeX Team, 2001-2002.
 // All Rights Reserved
 //
 //
 //  Copyright 2003 (c) Mathieu Roy <yeupou@gnu.org>
-//  
+//
 //
 //
 // This program is free software; you can redistribute it and/or
@@ -32,7 +32,7 @@
 //
 // Originally written by Laurent Julliard 2001, 2002, CodeX Team, Xerox
 
-if ($group_id && member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'2')) 
+if ($group_id && member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'2'))
 {
 
   // Initialize the global data structure before anything else
@@ -40,17 +40,17 @@ if ($group_id && member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).
 
   include ($GLOBALS['sys_urlroot'].'/include/HTML_Graphs.php');
 
-  if ($field) 
+  if ($field)
     {
-      if ($field == 'aging') 
+      if ($field == 'aging')
 	{
-	  trackers_header(array ("title"=>"Aging Report"));
-	  echo "\n<H1>Aging Report</H1>";
+	  trackers_header(array ("title"=>_("Aging Report")));
+	  echo "\n<h1>"._("Aging Report")."</h1>";
 
 	  $time_now=time();
 	  //			echo $time_now."<P>";
 
-	  for ($counter=1; $counter<=8; $counter++) 
+	  for ($counter=1; $counter<=8; $counter++)
 	    {
 
 	      $start=($time_now-($counter*604800));
@@ -64,11 +64,11 @@ if ($group_id && member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).
 	      $values[$counter-1]=db_result($result, 0,0);
 	    }
 
-	  GraphIt($names, $values, "Average Turnaround Time For Closed Items");
+	  GraphIt($names, $values, _("Average Turnaround Time For Closed Items"));
 
-	  echo "<P>";
+	  echo "<p>";
 
-	  for ($counter=1; $counter<=8; $counter++) 
+	  for ($counter=1; $counter<=8; $counter++)
 	    {
 
 	      $start=($time_now-($counter*604800));
@@ -82,11 +82,11 @@ if ($group_id && member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).
 	      $values[$counter-1]=db_result($result, 0,0);
 	    }
 
-	  GraphIt($names, $values, "Number of Items Opened");
+	  GraphIt($names, $values, _("Number of Items Opened"));
 
-	  echo "<P>";
+	  echo "<p>";
 
-	  for ($counter=1; $counter<=8; $counter++) 
+	  for ($counter=1; $counter<=8; $counter++)
 	    {
 
 	      $start=($time_now-($counter*604800));
@@ -100,38 +100,38 @@ if ($group_id && member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).
 	      $values[$counter-1]=db_result($result, 0,0);
 	    }
 
-	  GraphIt($names, $values, "Number of Items Still Open");
+	  GraphIt($names, $values, _("Number of Items Still Open"));
 
-	  echo "<P>";
+	  echo "<p>";
 
 	  trackers_footer(array());
 
-	} 
+	}
       else
 	{
 
-	  // It's any of the select box field. 
+	  // It's any of the select box field.
 
 	  $label = trackers_data_get_label($field);
-	  trackers_header(array ("title"=>"Items By $label"));
+	  trackers_header(array ("title"=> sprintf(_("Items by '%s'"), $label)));
 
 	  // Make sure it is a correct field
 	  if (trackers_data_is_special($field) || !trackers_data_is_used($field) ||
-	      !trackers_data_is_select_box($field) ) 
+	      !trackers_data_is_select_box($field) )
 	    {
 
-	      echo "<h2>Can't generate report for field $label";
+	      echo "<h2>".sprintf(_("Can't generate report for field %s"), $label)."</h2>";
 
-	    } 
+	    }
 	  else
 	    {
 
-	      echo "\n<H2>Items by $label</H2>";
+	      echo "\n<h2>".sprintf(_("Items by '%s'"), $label)."</h2>";
 
-	      // First graph the bug distribution for Open bugs only	
+	      // First graph the bug distribution for Open bugs only
 	      // Open means not status is neither closed (3) and nor Declined (7)
 	      // and resolution is not equal to Invalid (2)
-	      if ($field == 'assigned_to') 
+	      if ($field == 'assigned_to')
 		{
 
 		  $sql="SELECT user.user_name, count(*) AS Count FROM user,".ARTIFACT." ".
@@ -140,7 +140,7 @@ if ($group_id && member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).
 		     "".ARTIFACT.".resolution_id <> '2' AND ".ARTIFACT.".group_id='$group_id' ".
 		     "GROUP BY user_name";
 
-		} 
+		}
 	      else
 		{
 
@@ -159,20 +159,20 @@ if ($group_id && member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).
 		}
 
 	      $result=db_query($sql);
-	      if ($result && db_numrows($result) > 0) 
+	      if ($result && db_numrows($result) > 0)
 		{
-		  GraphResult($result,"Open Bugs By '$label'");
-		} 
-	      else
-		{ 
-		  echo "<H3>Open Items By $label</H3>";
-		  echo "No data found to report - Field probably not used";
+		  GraphResult($result,sprintf(_("Open Bugs By '%s'"), $label));
 		}
-	      echo "<P>";
+	      else
+		{
+		  echo "<h3>".sprintf(_("Open Items By '%s'"), $label)."</h3>";
+		  echo _("No data found to report - Field probably not used");
+		}
+	      echo "<p>";
 
 	      //Second  graph the bug distribution for all bugs only
 
-	      if ($field == 'assigned_to') 
+	      if ($field == 'assigned_to')
 		{
 
 		  $sql="SELECT user.user_name, count(*) AS Count FROM user,bug ".
@@ -180,7 +180,7 @@ if ($group_id && member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).
 		     "".ARTIFACT.".resolution_id <> '2' AND ".ARTIFACT.".group_id='$group_id' ".
 		     "GROUP BY user_name";
 
-		} 
+		}
 	      else
 		{
 
@@ -193,42 +193,44 @@ if ($group_id && member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).
 		     "GROUP BY value_id";
 		}
 	      $result=db_query($sql);
-	      if ($result && db_numrows($result) > 0) 
+	      if ($result && db_numrows($result) > 0)
 		{
-		  GraphResult($result,"All Items By $label");
-		} 
+		  GraphResult($result,sprintf(_("All Items By %s"), $label));
+		}
 	      else
 		{
-		  echo "<H3>All Items By $label</H3>";
-		  echo "No data found to report - Field probably not used";
+		  echo "<h3>".sprintf(_("All Items By %s"), $label)."</h3>";
+		  echo _("No data found to report - Field probably not used");
 		}
 
 	      trackers_footer(array());
 	    }
 	}
 
-    } 
+    }
   else
     {
       /*
 	  Show main page
       */
-      trackers_header(array ("title"=>"Reporting System"));
+      trackers_header(array ("title"=>_("Reporting System")));
 
-      echo "\n<H1>Item Reporting System</H1>";
-      echo "\n<P>";
-      echo "\n<A HREF=\"reporting.php?group_id=$group_id&field=aging\">Aging Report</A><BR>";
+      echo "\n<h1>"._("Item Reporting System")."</h1>";
+      echo "\n<p>";
+      echo "\n<a href=\"reporting.php?group_id=$group_id&field=aging\">"._("Aging Report")."</a><br />";
 
-      while ($field = trackers_list_all_fields()) 
+      while ($field = trackers_list_all_fields())
 	{
 
-	  if (trackers_data_is_special($field)) 
+	  if (trackers_data_is_special($field))
 	    { continue;}
 
-	  if (trackers_data_is_select_box($field) && trackers_data_is_used($field)) 
+	  if (trackers_data_is_select_box($field) && trackers_data_is_used($field))
 	    {
 
-	      echo "\n<A HREF=\"reporting.php?group_id=$group_id&field=$field\">Items by '".trackers_data_get_label($field)."'</A><BR>";
+	      echo "\n<a href=\"reporting.php?group_id=$group_id&field=$field\">";
+	      printf(_("Items by '%s'"), trackers_data_get_label($field));
+	      echo "</a><br />\n";
 	    }
 	}
 
@@ -236,16 +238,16 @@ if ($group_id && member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).
 
     }
 
-} 
+}
 else
 {
 
   //browse for group first message
 
-  if (!$group_id) 
+  if (!$group_id)
     {
       exit_no_group();
-    } 
+    }
   else
     {
       exit_permission_denied();
