@@ -1,68 +1,62 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: utils.php,v 1.53 2004/01/31 00:56:18 yeupou Exp $
-//
-//
-// 
-// Copyright 1999-2000 (c) The SourceForge Crew
-//
-//
-//  Copyright (C) 2000-2003 Free Software Foundation,
-//                          Mathieu Roy <yeupou@gnu.org>,
-// 
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
-
-// Many functions in this file do not set sys_debug_where, they are too
-// low level ones, they are not the functions that can call dbg().
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: utils.php,v 1.57 2004/03/07 12:51:01 yeupou Exp $
+#
+#  Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2000-2003 (c) Free Software Foundation
+#
+#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>,
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 
-// This function permit including site specific content with ease
-function utils_get_content ($file) 
+# Many functions in this file do not set sys_debug_where, they are too
+# low level ones, they are not the functions that can call dbg().
+
+
+# This function permit including site specific content with ease
+function utils_get_content ($file)
 {
-  if (is_file($GLOBALS['sys_incdir'].'/'.$file.'.'.$GLOBALS['locale'])) 
+  if (is_file($GLOBALS['sys_incdir'].'/'.$file.'.'.$GLOBALS['locale']))
     {
-      // there is localized version of the file :
+      # there is localized version of the file :
       include($GLOBALS['sys_incdir'].'/'.$file.'.'.$GLOBALS['locale']);
-    } 
+    }
   elseif (is_file($GLOBALS['sys_incdir'].'/'.$file.'.txt'))
     {
       include($GLOBALS['sys_incdir'].'/'.$file.'.txt');
     }
   else
     {
-      fb(sprintf(_("warning: Savannah was not able to read \"%s\" site-specific information, please contact administrators"), $file), 1);
+      fb(sprintf(_("Warning: Savane was not able to read \"%s\" site-specific information, please contact administrators"), $file), 1);
     }
 }
 
-// Make sure that to avoid malicious file paths
-function utils_check_path ($path) 
+# Make sure that to avoid malicious file paths
+function utils_check_path ($path)
 {
-  if (eregi(".*\.\.\/.*", $path)) 
+  if (eregi(".*\.\.\/.*", $path))
     {
       exit_error('Error','Malformed url');
     }
 }
 
-// In a string, replace %PROJECT by the group_name
-// (useful for group type configuration)
+# In a string, replace %PROJECT by the group_name
+# (useful for group type configuration)
 function utils_makereal ($data, $string="%PROJECT", $replacement=0)
 {
   if (!$replacement)
@@ -71,44 +65,44 @@ function utils_makereal ($data, $string="%PROJECT", $replacement=0)
 }
 
 
-// This function returns a string of the date $value with the format $format
-// and if this date is not set, return the default value $default_value
-function format_date ($format,$value,$default_value = '-') 
+# This function returns a string of the date $value with the format $format
+# and if this date is not set, return the default value $default_value
+function format_date ($format,$value,$default_value = '-')
 {
-  if ($value == 0) 
+  if ($value == 0)
     {
       return $default_value;
 
-    } 
-  else 
+    }
+  else
     {
-      if ($format) 
+      if ($format)
 	{
 	  return date($format,$value);
-	} 
-      else 
+	}
+      else
 	{
 	  return strftime('%a %x '._("at").' %R',$value);
 	}
     }
 }
 
-// Convert a date as used in the bug tracking system and other services (YYYY-MM-DD)
-// into a Unix time
-// Returns a list with two values: the unix time and a boolean saying whether the conversion
-// went well (true) or bad (false)
+# Convert a date as used in the bug tracking system and other services (YYYY-MM-DD)
+# into a Unix time
+# Returns a list with two values: the unix time and a boolean saying whether the conversion
+# went well (true) or bad (false)
 function utils_date_to_unixtime ($date)
 {
   $res = preg_match("/\s*(\d+)-(\d+)-(\d+)/",$date,$match);
-  if ($res == 0) 
+  if ($res == 0)
     { return array(0,false); }
   list(,$year,$month,$day) = $match;
   $time = mktime(0, 0, 0, $month, $day, $year);
-  //echo "<br>DBG Matching date $date -> year $year, month $month,day $day -> time = $time<br>";
+  #echo "<br>DBG Matching date $date -> year $year, month $month,day $day -> time = $time<br>";
   return array($time,true);
 }
 
-function utils_read_file($filename) 
+function utils_read_file($filename)
 {
   @$fp = fopen($filename, "r");
   if ($fp)
@@ -120,21 +114,21 @@ function utils_read_file($filename)
   return false;
 }
 
-function utils_filesize($filename, $file_size=0) 
+function utils_filesize($filename, $file_size=0)
 {
-  // If file size is defined, assume that we just want an unit conversion.
-  if (!$file_size) 
+  # If file size is defined, assume that we just want an unit conversion.
+  if (!$file_size)
     {   $file_size = filesize($filename); }
 
-  if ($file_size >= 1048576) 
+  if ($file_size >= 1048576)
     {
       $file_size = round($file_size / 1048576 * 100) / 100 . _("MB");
     }
-  elseif ($file_size >= 1024) 
+  elseif ($file_size >= 1024)
     {
       $file_size = round($file_size / 1024 * 100) / 100 . _("KB");
-    } 
-  else 
+    }
+  else
     {
       $file_size = $file_size . _("B");
     }
@@ -142,62 +136,62 @@ function utils_filesize($filename, $file_size=0)
   return $file_size;
 }
 
-function utils_fileextension($filename) 
+function utils_fileextension($filename)
 {
- 
+
   $ext = substr(basename($filename), strrpos(basename($filename),".") + 1);
-  if ($ext==gz || $ext==bz2) 
+  if ($ext==gz || $ext==bz2)
     {
       $ext = substr(basename($filename), strrpos(basename($filename),".") - 3);
     }
-  if ($ext==rpm) 
+  if ($ext==rpm)
     {
       $long_ext = _("rpm package");
     }
-  if ($ext==deb) 
+  if ($ext==deb)
     {
       $long_ext = _("debian package");
     }
-  if ($ext==deb || $ext==rpm) 
+  if ($ext==deb || $ext==rpm)
     {
       $arch_type = substr(basename($filename), strrpos(basename($filename),".") - 3);
-      if ($arch_type == "src.".$ext) 
+      if ($arch_type == "src.".$ext)
 	{
 	  $long_ext = sprintf(_("source %s"), $long_ext);
 	}
-      if ($arch_type == "rch.".$ext) 
+      if ($arch_type == "rch.".$ext)
 	{
 	  $long_ext = sprintf(_("arch independant %s"), $long_ext);
 	}
-      if ($arch_type == "386.".$ext) 
+      if ($arch_type == "386.".$ext)
 	{
 	  $long_ext = sprintf(_("%s for i386 (ix86)"), $long_ext);
 	}
-      if ($arch_type == "586.".$ext) 
+      if ($arch_type == "586.".$ext)
 	{
 	  $long_ext = sprintf(_("%s for i586"), $long_ext);
 	}
-      if ($arch_type == "686.".$ext) 
+      if ($arch_type == "686.".$ext)
 	{
 	  $long_ext = sprintf(_("%s for i686"), $long_ext);
 	}
-      if ($arch_type == "a64.".$ext) 
+      if ($arch_type == "a64.".$ext)
 	{
 	  $long_ext = sprintf(_("%s for Itanium 64"), $long_ext);
 	}
-      if ($arch_type == "arc.".$ext) 
+      if ($arch_type == "arc.".$ext)
 	{
 	  $long_ext = sprintf(_("%s for Sparc"), $long_ext);
 	}
-      if ($arch_type == "pha.".$ext) 
+      if ($arch_type == "pha.".$ext)
 	{
 	  $long_ext = sprintf(_("%s for Alpha"), $long_ext);
 	}
-      if ($arch_type == "ppc.".$ext) 
+      if ($arch_type == "ppc.".$ext)
 	{
 	  $long_ext = sprintf(_("%s for PowerPC"), $long_ext);
 	}
-      if ($arch_type == "390.".$ext) 
+      if ($arch_type == "390.".$ext)
 	{
 	  $long_ext = sprintf(_("%s for s390"), $long_ext);
 	}
@@ -206,7 +200,7 @@ function utils_fileextension($filename)
   return $ext;
 }
 
-function utils_prep_string_for_sendmail($body) 
+function utils_prep_string_for_sendmail($body)
 {
   $body=str_replace("\\","\\\\",$body);
   $body=str_replace("\"","\\\"",$body);
@@ -215,9 +209,9 @@ function utils_prep_string_for_sendmail($body)
   return $body;
 }
 
-function utils_unconvert_htmlspecialchars($string) 
+function utils_unconvert_htmlspecialchars($string)
 {
-  if (strlen($string) < 1) 
+  if (strlen($string) < 1)
     {
       return '';
     }
@@ -232,21 +226,21 @@ function utils_unconvert_htmlspecialchars($string)
     }
 }
 
-// transform homepage url in the same way than $project->getUrl("homepage")
-// we shouldnt use this but $project->getUrl("homepage")
-function utils_gethomepage($html_cvs, $isgnu, $unix_group_name) 
+# transform homepage url in the same way than $project->getUrl("homepage")
+# we shouldnt use this but $project->getUrl("homepage")
+function utils_gethomepage($html_cvs, $isgnu, $unix_group_name)
 {
   print 'This function should not be used, report it to savannah-hackers@gnu.org';
-  
+
 }
 
-function utils_remove_htmlheader($string) 
+function utils_remove_htmlheader($string)
 {
   $string = eregi_replace('(^.*<html[^>]*>.*<body[^>]*>)|(</body[^>]*>.*</html[^>]*>.*$)', '', $string);
   return $string;
 }
 
-function utils_result_column_to_array($result, $col=0) 
+function utils_result_column_to_array($result, $col=0)
 {
   /*
 		Takes a result set and turns the optional column into
@@ -254,10 +248,10 @@ function utils_result_column_to_array($result, $col=0)
   */
   $rows=db_numrows($result);
 
-  if ($rows > 0) 
+  if ($rows > 0)
     {
       $arr=array();
-      for ($i=0; $i<$rows; $i++) 
+      for ($i=0; $i<$rows; $i++)
 	{
 	  $arr[$i]=db_result($result,$i,$col);
 	}
@@ -269,7 +263,7 @@ function utils_result_column_to_array($result, $col=0)
   return $arr;
 }
 
-function result_column_to_array($result, $col=0) 
+function result_column_to_array($result, $col=0)
 {
   /*
 		backwards compatibility
@@ -277,47 +271,47 @@ function result_column_to_array($result, $col=0)
   return utils_result_column_to_array($result, $col);
 }
 
-function utils_wrap_find_space($string,$wrap) 
+function utils_wrap_find_space($string,$wrap)
 {
   $start=$wrap-5;
   $try=1;
   $found=false;
-	
-  while (!$found) 
+
+  while (!$found)
     {
-      //find the first space starting at $start
+      #find the first space starting at $start
       $pos=@strpos($string,' ',$start);
-		
-      //if that space is too far over, go back and start more to the left
-      if (($pos > ($wrap+5)) || !$pos) 
+
+      #if that space is too far over, go back and start more to the left
+      if (($pos > ($wrap+5)) || !$pos)
 	{
 	  $try++;
 	  $start=($wrap-($try*5));
-	  //if we've gotten so far left , just truncate the line
-	  if ($start<=10) 
+	  #if we've gotten so far left , just truncate the line
+	  if ($start<=10)
 	    {
 	      return $wrap;
-	    }       
+	    }
 	  $found=false;
 	}
       else
 	{
 	  $found=true;
-	}       
-    }       
-	
+	}
+    }
+
   return $pos;
 }
 
-function utils_line_wrap ($text, $wrap = 78, $break = "\n") 
+function utils_line_wrap ($text, $wrap = 78, $break = "\n")
 {
   $paras = explode("\n", $text);
-			
+
   $result = array();
   $i = 0;
-  while ($i < count($paras)) 
+  while ($i < count($paras))
     {
-      if (strlen($paras[$i]) <= $wrap) 
+      if (strlen($paras[$i]) <= $wrap)
 	{
 	  $result[] = $paras[$i];
 	  $i++;
@@ -325,11 +319,11 @@ function utils_line_wrap ($text, $wrap = 78, $break = "\n")
       else
 	{
 	  $pos=utils_wrap_find_space($paras[$i],$wrap);
-			
+
 	  $result[] = substr($paras[$i], 0, $pos);
-			
+
 	  $new = trim(substr($paras[$i], $pos, strlen($paras[$i]) - $pos));
-	  if ($new != '') 
+	  if ($new != '')
 	    {
 	      $paras[$i] = $new;
 	      $pos=utils_wrap_find_space($paras[$i],$wrap);
@@ -337,94 +331,94 @@ function utils_line_wrap ($text, $wrap = 78, $break = "\n")
 	  else
 	    {
 	      $i++;
-	    }       
-	}       
-    }		       
+	    }
+	}
+    }
   return implode($break, $result);
 }
 
-function utils_make_links ($data='',$group_id = 0) 
+function utils_make_links ($data='',$group_id = 0)
 {
-  if(empty($data)) 
+  if(empty($data))
     { return $data; }
 
   $lines = split("\n",$data);
-  while ( list ($key,$line) = each ($lines)) 
+  while ( list ($key,$line) = each ($lines))
     {
-      // Don't mess with html links already there
+      # Don't mess with html links already there
       $line = eregi_replace("<a href(.*)://(.*)://(.*)</a>","<a href\\1:##\\2:##\\3</a>",$line);
       $line = eregi_replace("<a href(.*)://(.*)</a>","<a href\\1:##\\2</a>",$line);
 
-      // Make usual links
+      # Make usual links
       $line = eregi_replace("([ \t]|^)www\."," http://www.",$line);
-      // FIXME: and &gt; broke the following regexp, so we do an
-      // ugly convert->work->convert.
-      // Please propose a better regexp.
+      # FIXME: and &gt; broke the following regexp, so we do an
+      # ugly convert->work->convert.
+      # Please propose a better regexp.
       $line = eregi_replace("&gt;", ">--", $line);
       $line = eregi_replace("(([a-z0-9_]|\\-|\\.)+://([^[:space:]><]*)([[:alnum:]-]))", "<a href=\"\\1\">\\1</a>", $line);
-      $line = eregi_replace("(([a-z0-9_]|\\-|\\.)+@([^[:space:]&><]*)([[:alnum:]-]))", "&lt;<a href=\"mailto:\\1\">\\1</a>&gt;", $line);
+      $line = eregi_replace("(([a-z0-9_]|\\-|\\.)+@([^[:space:]&><]*)([[:alnum:]-]))", "<a href=\"mailto:\\1\">\\1</a>", $line);
       $line = eregi_replace(">--", "&gt;", $line);
 
-      // Don't mess with html links already there
+      # Don't mess with html links already there
       $line = eregi_replace(":##", "://", $line);
 
-      // Links between items
-      $line = eregi_replace("(bugs|bug)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."bugs/?func=detailitem&amp;item_id=\\2\">[bugs&nbsp;#\\2]</a>", $line); 
+      # Links between items
+      $line = eregi_replace("(bugs|bug)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."bugs/?func=detailitem&amp;item_id=\\2\">[bugs&nbsp;#\\2]</a>", $line);
       $line = eregi_replace("(support|sr)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."support/?func=detailitem&amp;item_id=\\2\">[support&nbsp;#\\2]</a>", $line);
       $line = eregi_replace("task[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."task/?func=detailitem&amp;item_id=\\1\">[task&nbsp;#\\1]</a>", $line);
       $line = eregi_replace("patch[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."patch/?func=detailitem&amp;item_id=\\1\">[patch&nbsp;#\\1]</a>", $line);
 
 
-  
+
       $lines[$key] = $line;
     }
   return join("\n", $lines);
-  
+
 }
 
-function utils_user_link ($username, $realname=0) 
+function utils_user_link ($username, $realname=0)
 {
-  if ( $username == 'None' || empty($username)) 
-    { 
-      return $username; 
+  if ( $username == 'None' || empty($username))
+    {
+      return $username;
     }
-  else 
+  else
     {
       $re = '<a href="'.$GLOBALS['sys_home'].'users/'.$username.'">';
-      if ($realname) 
+      if ($realname)
 	{
 	  $re .= $realname;
 	}
-      else 
+      else
 	{
 	  $re .= $username;
 	}
       $re .= '</a>';
-      
+
       return $re;
     }
 }
 
-function utils_double_diff_array($arr1, $arr2) 
+function utils_double_diff_array($arr1, $arr2)
 {
-  // first transform both arrays in hashes
+  # first transform both arrays in hashes
   reset($arr1); reset($arr2);
-  while ( list(,$v) = each($arr1)) 
+  while ( list(,$v) = each($arr1))
     { $h1[$v] = $v; }
-  while ( list(,$v) = each($arr2)) 
+  while ( list(,$v) = each($arr2))
     { $h2[$v] = $v; }
 
   $deleted = array();
-  while ( list($k,) = each($h1)) 
+  while ( list($k,) = each($h1))
     {
-      if (!isset($h2[$k])) 
+      if (!isset($h2[$k]))
 	{ $deleted[] = $k; }
     }
 
   $added = array();
-  while ( list($k,) = each($h2)) 
+  while ( list($k,) = each($h2))
     {
-      if (!isset($h1[$k])) 
+      if (!isset($h1[$k]))
 	{ $added[] = $k; }
     }
 
@@ -433,22 +427,22 @@ function utils_double_diff_array($arr1, $arr2)
 
 function utils_registration_history ($unix_group_name)
 {
-  if ($unix_group_name != "") 
+  if ($unix_group_name != "")
     {
       $register_discard = `grep $unix_group_name /var/log/sv_register_discard.log`;
-      if ($register_discard != "") 
+      if ($register_discard != "")
 	{
 	  return '<b>Registration history:</b><br>'.nl2br($register_discard);
 	}
     }
 }
 
-function show_priority_colors_key() 
+function show_priority_colors_key()
 {
   print '<br><br><table border=0><tr>';
   echo '<td><b>'._("Priority Colors").":</b> &nbsp;&nbsp;&nbsp;</td>\n";
-	
-  for ($i=1; $i<10; $i++) 
+
+  for ($i=1; $i<10; $i++)
     {
       print '<td class="'.get_priority_color($i).'">'.$i."</td>\n";
     }
@@ -456,18 +450,18 @@ function show_priority_colors_key()
 }
 
 
-function get_priority_color ($index) 
+function get_priority_color ($index)
 {
   /*
 		Return the color value for the index that was passed in
 		(defined in $sys_urlroot/themes/<selected theme>/theme.php)
   */
   global $bgpri;
-	
+
   return $bgpri[$index];
 }
 
-function build_priority_select_box ($name="priority", $checked_val="5") 
+function build_priority_select_box ($name="priority", $checked_val="5")
 {
   /*
 		Return a select box of standard priorities.
@@ -489,21 +483,21 @@ function build_priority_select_box ($name="priority", $checked_val="5")
 
 }
 
-// ########################################### checkbox array
-// ################# mostly for group languages and environments
+# ########################################### checkbox array
+# ################# mostly for group languages and environments
 
-function utils_buildcheckboxarray($options,$name,$checked_array) 
+function utils_buildcheckboxarray($options,$name,$checked_array)
 {
   $option_count=count($options);
   $checked_count=count($checked_array);
 
-  for ($i=1; $i<=$option_count; $i++) 
+  for ($i=1; $i<=$option_count; $i++)
     {
       echo '
 			<BR><INPUT type="checkbox" name="'.$name.'" value="'.$i.'"';
-      for ($j=0; $j<$checked_count; $j++) 
+      for ($j=0; $j<$checked_count; $j++)
 	{
-	  if ($i == $checked_array[$j]) 
+	  if ($i == $checked_array[$j])
 	    {
 	      echo ' CHECKED';
 	    }
@@ -512,13 +506,13 @@ function utils_buildcheckboxarray($options,$name,$checked_array)
     }
 }
 
-// deprecated name
-function GraphResult($result,$title) 
+# deprecated name
+function GraphResult($result,$title)
 {
   utils_graph_result($result, $title);
 }
 
-function utils_graph_result ($result,$title) 
+function utils_graph_result ($result,$title)
 {
 
   /*
@@ -537,8 +531,8 @@ function utils_graph_result ($result,$title)
 		db_ should be replaced with your database, aka mysql_ or pg_
   */
   $rows=db_numrows($result);
-  
-  if ((!$result) || ($rows < 1)) 
+
+  if ((!$result) || ($rows < 1))
     {
       echo 'None Found.';
     }
@@ -547,15 +541,15 @@ function utils_graph_result ($result,$title)
       $names=array();
       $values=array();
 
-      for ($j=0; $j<db_numrows($result); $j++) 
+      for ($j=0; $j<db_numrows($result); $j++)
 	{
-	  if (db_result($result, $j, 0) != '' && db_result($result, $j, 1) != '' ) 
+	  if (db_result($result, $j, 0) != '' && db_result($result, $j, 1) != '' )
 	    {
 	      $names[$j]= db_result($result, $j, 0);
 	      $values[$j]= db_result($result, $j, 1);
 	    }
 	}
-      
+
       /*
 		This is another function detailed below
       */
@@ -564,14 +558,14 @@ function utils_graph_result ($result,$title)
 }
 
 
-// deprecated name
-function GraphIt ($name_string,$value_string,$title) 
+# deprecated name
+function GraphIt ($name_string,$value_string,$title)
 {
   utils_graph_it($name_string,$value_string,$title);
 }
 
 
-function utils_graph_it ($name_string,$value_string,$title) 
+function utils_graph_it ($name_string,$value_string,$title)
 {
 
   /*
@@ -584,7 +578,7 @@ function utils_graph_it ($name_string,$value_string,$title)
   */
   $bars=array();
 
-  for ($i = 0; $i < $counter; $i++) 
+  for ($i = 0; $i < $counter; $i++)
     {
       $bars[$i]=$GLOBALS['COLOR_LTBACK1'];
     }
@@ -597,15 +591,15 @@ function utils_graph_it ($name_string,$value_string,$title)
 
   $max_value=0;
 
-  for ($i = 0; $i < $counter; $i++) 
+  for ($i = 0; $i < $counter; $i++)
     {
-      if ($value_string[$i] > $max_value) 
+      if ($value_string[$i] > $max_value)
 	{
 	  $max_value=$value_string[$i];
 	}
     }
 
-  if ($max_value < 1) 
+  if ($max_value < 1)
     {
       $max_value=1;
     }
@@ -665,13 +659,13 @@ function utils_graph_it ($name_string,$value_string,$title)
 		<!-- end outer graph table -->';
 }
 
-// deprecated name 
-function ShowResultSet($result,$title="Untitled",$linkify=false)  
+# deprecated name
+function ShowResultSet($result,$title="Untitled",$linkify=false)
 {
   utils_show_result_set($result,$title,$linkify);
 }
 
-function utils_show_result_set ($result,$title="Untitled",$linkify=false)  
+function utils_show_result_set ($result,$title="Untitled",$linkify=false)
 {
   global $group_id,$HTML;
   /*
@@ -696,35 +690,35 @@ function utils_show_result_set ($result,$title="Untitled",$linkify=false)
     /*  Create  the  headers  */
     echo '
 			<tr>';
-    for ($i=0; $i < $cols; $i++) 
+    for ($i=0; $i < $cols; $i++)
       {
 	echo '<td><B>'.db_fieldname($result,  $i).'</B></TD>';
       }
     echo '</tr>';
 
     /*  Create the rows  */
-    for ($j = 0; $j < $rows; $j++) 
+    for ($j = 0; $j < $rows; $j++)
       {
 	echo '<TR class="'. html_get_alt_row_color($j) .'">';
-	for ($i = 0; $i < $cols; $i++) 
+	for ($i = 0; $i < $cols; $i++)
 	  {
-	    if ($linkify && $i == 0) 
+	    if ($linkify && $i == 0)
 	      {
 		$link = '<A HREF="'.$PHP_SELF.'?';
 		$linkend = '</A>';
-		if ($linkify == "bug_cat") 
+		if ($linkify == "bug_cat")
 		  {
 		    $link .= 'group_id='.$group_id.'&bug_cat_mod=y&bug_cat_id='.db_result($result, $j, 'bug_category_id').'">';
-		  } else if($linkify == "bug_group") 
+		  } else if($linkify == "bug_group")
 		    {
 		      $link .= 'group_id='.$group_id.'&bug_group_mod=y&bug_group_id='.db_result($result, $j, 'bug_group_id').'">';
-		    } else if($linkify == "patch_cat") 
+		    } else if($linkify == "patch_cat")
 		      {
 			$link .= 'group_id='.$group_id.'&patch_cat_mod=y&patch_cat_id='.db_result($result, $j, 'patch_category_id').'">';
-		      } else if($linkify == "support_cat") 
+		      } else if($linkify == "support_cat")
 			{
 			  $link .= 'group_id='.$group_id.'&support_cat_mod=y&support_cat_id='.db_result($result, $j, 'support_category_id').'">';
-			} else if($linkify == "pm_project") 
+			} else if($linkify == "pm_project")
 			  {
 			    $link .= 'group_id='.$group_id.'&project_cat_mod=y&project_cat_id='.db_result($result, $j, 'group_project_id').'">';
 			  }
@@ -751,15 +745,15 @@ function utils_show_result_set ($result,$title="Untitled",$linkify=false)
 }
 
 
-// Clean up email address (remove spaces...) and put to lower case
-function utils_cleanup_emails ($addresses) 
+# Clean up email address (remove spaces...) and put to lower case
+function utils_cleanup_emails ($addresses)
 {
   return strtolower(preg_replace("/\s/","", $addresses));
 }
 
-// Clean up email address (remove spaces...) and add @... if it is a simple
-// login name
-function utils_normalize_email ($address) 
+# Clean up email address (remove spaces...) and add @... if it is a simple
+# login name
+function utils_normalize_email ($address)
 {
   global $sys_users_host;
   $address = utils_cleanup_emails($address);
@@ -770,47 +764,47 @@ function utils_normalize_email ($address)
 }
 
 
-function utils_antispam_email ($address) 
+function utils_antispam_email ($address)
 {
   $fakemail = preg_replace("/\\@/",' '._("--AT--").' ', $address);
   $fakemail = preg_replace("/\\./",' '._("--DOT--").' ', $fakemail);
   return $fakemail;
 }
 
-// Clean up email address (remove spaces...) and split comma separated emails
-function utils_split_emails($addresses) 
+# Clean up email address (remove spaces...) and split comma separated emails
+function utils_split_emails($addresses)
 {
   $addresses = utils_cleanup_emails($addresses);
   return split(',',$addresses);
 }
 
-// Email Verification
+# Email Verification
 function validate_email ($address)
 {
   return (ereg('^[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+'. '@'. '[-!#$%&\'*+\\/0-9=?A-Z^_`a-z{|}~]+\.' . '[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+$', $address));
 }
 
-// Verification of comma separated list of email addresses
-function validate_emails ($addresses) 
+# Verification of comma separated list of email addresses
+function validate_emails ($addresses)
 {
   $arr = utils_split_emails($addresses);
-  while (list(, $addr) = each ($arr)) 
+  while (list(, $addr) = each ($arr))
     {
-      if (!validate_email($addr)) 
+      if (!validate_email($addr))
 	{ return false;}
-    }	    
+    }
   return true;
 }
 
-function utils_is_valid_filename ($file) 
+function utils_is_valid_filename ($file)
 {
-  if (ereg("[]~`! ~@#\"$%^,&*();=|[{}<>?/]",$file)) 
+  if (ereg("[]~`! ~@#\"$%^,&*();=|[{}<>?/]",$file))
     {
       return false;
     }
   else
     {
-      if (strstr($file,'..')) 
+      if (strstr($file,'..'))
 	{
 	  return false;
 	}
@@ -820,20 +814,20 @@ function utils_is_valid_filename ($file)
 	}
     }
 }
-  
-// alias
+
+# alias
 function util_debug ($msg)
 {
   dbg($msg);
 }
 
-// alias
+# alias
 function debug ($msg)
 {
   dbg($msg);
 }
 
-// add debugging information
+# add debugging information
 function dbg ($msg)
 {
   if ($GLOBALS['sys_debug_on'])
@@ -844,34 +838,34 @@ function dbg ($msg)
 }
 
 
-// alias
+# alias
 function util_feedback ($msg, $error=0)
 {
   fb($msg, $error);
 }
 
-// alias
+# alias
 function feedback ($msg, $error=0)
 {
   fb($msg, $error);
 }
 
-// add feedback information
+# add feedback information
 function fb ($msg, $error=0)
 {
-  // Increment feedback count
+  # Increment feedback count
   $GLOBALS['feedback_count']++;
 
-  // Remove the dot at the end, if existing
+  # Remove the dot at the end, if existing
   if (substr($msg, -1) == ".")
     {
       $msg = substr($msg, 0, (strlen($msg)-1));
     }
 
-  // First letter capitalized, that's all
-  $msg = strtoupper(substr($msg, 0, 1)).strtolower(substr($msg, 1, strlen($msg))).' [#'.$GLOBALS['feedback_count'].']'._("; ");
+  # First letter capitalized, that's all
+  $msg = strtoupper(substr($msg, 0, 1)).strtolower(substr($msg, 1, strlen($msg))).' [#'.$GLOBALS['feedback_count'].']; ';
 
-  // feed  
+  # feed
   if (!$error)
     {
       dbg("Add feedback #".$GLOBALS['feedback_count']);
@@ -884,25 +878,25 @@ function fb ($msg, $error=0)
     }
 }
 
-// alias
+# alias
 function util_help ($text, $explanation_array)
 {
   help($text, $explanation_array);
 }
 
-// print help about a word
-//   $text  is the sentence where ballons are
-//   $explanation_array is the table word->explanation, must be in the 
-//   array syntax.
+# print help about a word
+#   $text  is the sentence where ballons are
+#   $explanation_array is the table word->explanation, must be in the
+#   array syntax.
 function help ($text, $explanation_array)
 {
   while (list($word,$explanation) = each($explanation_array))
     {
       $text = str_replace($word,
-			     '<font class="help" title="'.$explanation.'">'.$word.'</font>', 
+			     '<font class="help" title="'.$explanation.'">'.$word.'</font>',
 			     $text);
     }
   return $text;
 }
 
-?>
\ No newline at end of file
+?>
