@@ -2,14 +2,14 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: editjob.php,v 1.14 2004/01/31 00:56:19 yeupou Exp $
+// $Id: editjob.php,v 1.17 2004/03/04 18:55:45 toddy Exp $
+//
 //
-// 
 // Copyright 1999-2000 (c) The SourceForge Crew
 //
 //
 //  Copyright 2000-2003 (c) Free Software Foundation
-// 
+//
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either version 2
@@ -50,7 +50,7 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
       $job_id=db_insertid($result);
       fb(_("JOB inserted successfully"));
     }
-      
+
   } else if ($update_job) {
     /*
 			update the job's description, status, etc
@@ -59,7 +59,7 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
       //required info
       exit_error(_("error - missing info"),_("Fill in all required fields"));
     }
-      
+
     $sql="UPDATE people_job SET title='$title',description='$description',status_id='$status_id',category_id='$category_id' ".
        "WHERE job_id='$job_id' AND group_id='$group_id'";
     $result=db_query($sql);
@@ -69,7 +69,7 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
     } else {
       fb(_("JOB updated successfully"));
     }
-      
+
   } else if ($add_to_job_inventory) {
     /*
 			add item to job inventory
@@ -78,14 +78,14 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
       //required info
       exit_error(_("error - missing info"),_("Fill in all required fields"));
     }
-      
+
     if (people_verify_job_group($job_id,$group_id)) {
       people_add_to_job_inventory($job_id,$skill_id,$skill_level_id,$skill_year_id);
-      fb(_("JOB update successful"));
+      fb(_("JOB updated successfully"));
     } else {
       fb(_("JOB update failed - wrong project_id"));
     }
-      
+
   } else if ($update_job_inventory) {
     /*
 			Change Skill level, experience etc.
@@ -94,7 +94,7 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
       //required info
       exit_error(_("error - missing info"),_("Fill in all required fields"));
     }
-      
+
     if (people_verify_job_group($job_id,$group_id)) {
       $sql="UPDATE people_job_inventory SET skill_level_id='$skill_level_id',skill_year_id='$skill_year_id' ".
 	 "WHERE job_id='$job_id' AND job_inventory_id='$job_inventory_id'";
@@ -108,7 +108,7 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
     } else {
       fb(_("JOB skill update failed - wrong project_id"));
     }
-      
+
   } else if ($delete_from_job_inventory) {
     /*
 			remove this skill from this job
@@ -117,7 +117,7 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
       //required info
       exit_error(_("error - missing info"),_("Fill in all required fields"));
     }
-      
+
     if (people_verify_job_group($job_id,$group_id)) {
       $sql="DELETE FROM people_job_inventory WHERE job_id='$job_id' AND job_inventory_id='$job_inventory_id'";
       $result=db_query($sql);
@@ -130,9 +130,9 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
     } else {
       fb(_("JOB skill delete failed - wrong project_id"));
     }
-      
+
   }
-    
+
   /*
 		Fill in the info to create a job
                 Only if we have a job id specified
@@ -147,12 +147,12 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
     if (!$result || db_numrows($result) < 1) {
       echo db_error();
       fb(_("POSTING fetch FAILED"));
-      echo '<h2>'._("No Such posting For This Project").'</h2>';
+      echo '<h2>'._("No Such Posting For This Project").'</h2>';
     } else {
-	
+
       // we get site-specific content
       utils_get_content("people/editjob");
-	
+
       echo '
 		<form action="'.$PHP_SELF.'" method="POST">
 		<input type="hidden" name="group_id" value="'.$group_id.'">
@@ -162,7 +162,7 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
 	. people_job_category_box('category_id',db_result($result,0,'category_id')) .'
 		<p>
 		<b>'
-	._("Status:").'</b><br>'
+	._("Status").':</b><br>'
 	. people_job_status_box('status_id',db_result($result,0,'status_id')) .'
 		<p>
 		<b>'
@@ -175,23 +175,23 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
 		<p>
 		<input type="submit" name="update_job" value="'._("Update Descriptions").'">
 		</form>';
-	
+
       //now show the list of desired skills
       echo '<P>'.people_edit_job_inventory($job_id,$group_id);
       echo '<P><FORM ACTION="'.$GLOBALS['sys_home'].'people/" METHOD="POST"><INPUT TYPE="SUBMIT" NAME="SUBMIT" VALUE="Finished"></FORM>';
-	
+
     }
   } else {
 
     site_project_header(array('title'=>_("Looking for a job to Edit"),'group'=>$group_id,'toptab'=>'ahome'));
-      
+
     echo '<p>'
       ._("Here is a list of positions available for this project, choose the one you want to modify.").'</p>';
     echo people_show_project_jobs($group_id, $edit=1);
   }
-    
+
   site_project_footer(array());
-    
+
 } else {
   /*
 		Not logged in or insufficient privileges
@@ -203,4 +203,4 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
   }
 }
 
-?>
\ No newline at end of file
+?>
