@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: useradmin.php,v 1.3 2004/01/31 00:56:19 yeupou Exp $
+// $Id: useradmin.php,v 1.6 2004/03/06 16:53:35 toddy Exp $
 //
 //
 //  the Savannah Project
@@ -10,7 +10,7 @@
 //                     Derek Feichtinger <derek.feichtinger@cern.ch>,
 //                     Mathieu Roy <yeupou@gnu.org>,
 //
-// 
+//
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either version 2
@@ -29,11 +29,11 @@
 //
 //
 
-require "../../include/pre.php";  
+require "../../include/pre.php";
 
 session_require(array('group'=>$group_id,'admin_flags'=>'A'));
 
-function show_pending_users_list ($result, $group_id) 
+function show_pending_users_list ($result, $group_id)
 {
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_pending_users_list ($result, $group_id) ';
   global $PHP_SELF;
@@ -43,19 +43,19 @@ function show_pending_users_list ($result, $group_id)
 	<form action=\"$PHP_SELF\" method=\"post\">
 	<input type=\"HIDDEN\" name=\"action\" VALUE=\"approve_for_group\">
   <select name=\"user_id[]\" size=6 multiple>\n";
-  
+
   while ($usr = db_fetch_array($result)) {
     print "<option value=".$usr[user_id].">".$usr[realname].
       " (".$usr[user_name].")</option>\n";
     $exists=1;
   }
-  
-  if (!$exists) 
+
+  if (!$exists)
     {
       // Show none if the list is empty
       print '<option>'._("None Found").'</option>';
     }
-  
+
   print "</select>
 	<input type=\"HIDDEN\" name=\"group_id\" VALUE=\"$group_id\">
 	<P>
@@ -64,7 +64,7 @@ function show_pending_users_list ($result, $group_id)
 }
 
 
-function show_all_users_remove_list ($result, $group_id) 
+function show_all_users_remove_list ($result, $group_id)
 {
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_all_users_remove_list ($result, $group_id) ';  global $PHP_SELF;
   print "
@@ -74,16 +74,16 @@ function show_all_users_remove_list ($result, $group_id)
 	<form action=\"$PHP_SELF\" method=\"post\">
 	<input type=\"HIDDEN\" name=\"action\" VALUE=\"remove_from_group\">
   <select name=\"user_id[]\" size=\"6\" multiple>\n";
-  
+
   while ($usr = db_fetch_array($result)) {
-    if (!member_check($usr[user_id], $group_id, "A")) 
+    if (!member_check($usr[user_id], $group_id, "A"))
       {
 	print "<option value=".$usr[user_id].">".$usr[realname].
 	  " (".$usr[user_name].")</option>\n";
 	$exists=1;
       }
   }
-  
+
   if (!$exists) {
     // Show none if the list is empty
     print '<option>'._("None Found").'</option>';
@@ -95,13 +95,13 @@ function show_all_users_remove_list ($result, $group_id)
 	<p>
 	<input type=\"submit\" name=\"Submit\" value=\""._("Remove User(s) from Group")."\">
 	</form>";
-  
+
 }
 
-function show_all_users_add_searchbox ($group_id, $previous_search) 
+function show_all_users_add_searchbox ($group_id, $previous_search)
 {
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_all_users_add_searchbox ($group_id, $previous_search) ';  global $PHP_SELF;
-  print ' 
+  print '
         <h3><a name="searchuser"></a>'._("Adding User(s) to Group").'</h3>
 	<p>
         '._("You can search one or several users to add in the whole users database with the following search tool. A list of users, depending on the name(s) you'll type in this form, will be generated.").'
@@ -116,8 +116,8 @@ function show_all_users_add_searchbox ($group_id, $previous_search)
 }
 
 
-  
-function show_all_users_add_list ($result, $group_id) 
+
+function show_all_users_add_list ($result, $group_id)
 {
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_all_users_add_list ($result, $group_id) ';  global $PHP_SELF;
   print _("Below is the result of your search in the users database.")."
@@ -126,7 +126,7 @@ function show_all_users_add_list ($result, $group_id)
 	<form action=\"$PHP_SELF\" method=\"post\">
 	<input type=\"HIDDEN\" name=\"action\" VALUE=\"add_to_group\">
   <select name=\"user_id[]\" size=6 multiple>\n";
-  
+
   while ($usr = db_fetch_array($result)) {
       print "<option value=".$usr[user_id].">".$usr[realname].
 	" (".$usr[user_name].")</option>\n";
@@ -137,7 +137,7 @@ function show_all_users_add_list ($result, $group_id)
     // Show none if the list is empty
     print '<option>'._("None Found").'</option>';
   }
-  
+
   print "</select>
 	<br>
 	<input type=\"HIDDEN\" name=\"group_id\" VALUE=\"$group_id\">
@@ -148,15 +148,15 @@ function show_all_users_add_list ($result, $group_id)
 
 
 
-function show_bulk_add_users ($group_id) 
+function show_bulk_add_users ($group_id)
 {
 	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_bulk_add_users ($group_id) ';  print "<h3>"._("Have your file checked")."</h3>
-  
+
   "._("By submitting your file here, the format of the file and each user name, etc. will be checked.
   No modifications will be made to the Savannah user database.
   Feedback will be given on screen and by email.")."
   <br>
-  
+
 	<form action=\"bulk_admin_users.php?action=test&group_id=".$group_id."\" method=\"post\"  enctype=\"multipart/form-data\">
 	<input type=\"HIDDEN\" name=\"action\" VALUE=\"check\">
   <input type=\"file\" name=\"file\" size=\"40\">
@@ -169,11 +169,11 @@ function show_bulk_add_users ($group_id)
   </td></tr><tr><td class=\"boxitemalt\">
 
   <h3>"._("Have your file executed")."</h3>
-  
+
   "._("By submitting your file here, modifications will be made to the Savannah user database.
   Feedback will be given on screen and by email.")."
   <br>
-  
+
 	<form action=\"bulk_admin_users.php?action=execute&group_id=".$group_id."\" method=\"post\"  enctype=\"multipart/form-data\">
 	<input type=\"HIDDEN\" name=\"action\" VALUE=\"check\">
   <input type=\"file\" name=\"file\" size=\"40\">
@@ -182,7 +182,7 @@ function show_bulk_add_users ($group_id)
 	</P>
   </form>";
 }
-  
+
 // Administrative functions
 
 /*
@@ -192,7 +192,7 @@ if ($action=='add_to_group' && $user_id) {
   $sys_approved_user_permissions = $GLOBALS['sys_approved_user_permissions'];
   foreach ($user_id as $user) {
     member_add($user, $group_id);
-    sprintf(_(" User %s added to the project."), user_getname($user));
+    sprintf(' '._("User %s added to the project."), user_getname($user));
   }
 }
 
@@ -204,7 +204,7 @@ if ($action=='remove_from_group' && $user_id) {
     // Check if the users about to be removed are not admins
     if (!member_check($user, $group_id, "A")) {
       member_remove($user, $group_id);
-      sprintf(_(" User %s deleted from the project."), user_getname($user));;
+      sprintf(' '._("User %s deleted from the project."), user_getname($user));;
     }
   }
 }
@@ -216,14 +216,12 @@ if ($action=='approve_for_group' && $user_id) {
   foreach ($user_id as $user) {
     member_approve($user, $group_id);
     if($email=user_get_email($user)){
-      $message = _("You've been approved as a member of the group ").
-	 group_getname($group_id).
-	 _(" on ") . $GLOBALS['sys_name'] . _(", where you are registered as ") . user_getname($user) . ".\n\n".
-	 _("-- the ") . $GLOBALS['sys_name'] . _(" team.\n");
-      
+      $message = sprintf(_("You've been approved as a member of the group %s on %s,\nwhere you are registered as %s."), group_getname($group_id), $GLOBALS['sys_name'], user_getname($user)) . "\n\n".
+	 sprintf(_("-- the %s team."),$GLOBALS['sys_name'])."\n";
+
       sendmail_mail($GLOBALS['sys_replyto'] . "@".$GLOBALS['sys_lists_domain'],
 		    $email,
-		    _(" Project membership approved"),
+		    ' '._("Project membership approved"),
 		    $message);
     }
   }
@@ -242,18 +240,18 @@ site_project_header(array('title'=>_("Manage Members"),'group'=>$group_id,'topta
 if (!$group_id) {
 
   exit_error('No group id given', $group_id);
-  
+
 } else {
   /*
 		Show list for one group
   */
-  
+
   $HTML->box1_top(_("Member Administration for ").group_getname($group_id));
-  
+
   /*
         	Show a form so a user can be approved for this group
   */
-  
+
   $result =  db_query("SELECT user.user_id AS user_id, "
 		      . "user.user_name AS user_name, "
 		      . "user.realname AS realname "
@@ -261,9 +259,9 @@ if (!$group_id) {
 		      . "WHERE user.user_id=user_group.user_id AND user_group.group_id='$group_id' AND admin_flags='P'"
 		      . "ORDER BY user.user_name");
 
-  
+
   show_pending_users_list($result, $group_id);
-  
+
   print '<br></td></tr><tr><td class="boxitemalt">';
 
   /*
@@ -277,10 +275,10 @@ if (!$group_id) {
 		      . "ORDER BY user.user_name");
 
   show_all_users_remove_list($result, $group_id);
-  
-  
+
+
   print '<br></td></tr><tr><td class="boxitem">';
-  
+
   /*
         	Show a form so a user can be added to this group
   */
@@ -292,15 +290,15 @@ if (!$group_id) {
   $result = db_query("SELECT user_id, user_name, realname "
 		     . "FROM user "
 		     . "WHERE ((user_name LIKE '%$words1%') OR (realname LIKE '%$words2%')) AND (status='A') ORDER BY user_name LIMIT 0,26");
-		     
+
   show_all_users_add_searchbox($group_id, $words);
 
   if ($words) {
     show_all_users_add_list($result, $group_id);
   }
-  
+
   $HTML->box1_bottom();
-  
+
   print '<p></p>';
 
   /*
@@ -309,9 +307,9 @@ if (!$group_id) {
            FIXME: deactivated until we provide user documentation.
                  it could broke the database information
    $HTML->box1_top(_("Upload File to Bulk-manage Users"));
-  
-  show_bulk_add_users ($group_id);	
-  
+
+  show_bulk_add_users ($group_id);
+
   $HTML->box1_bottom();
   */
 }
