@@ -1,34 +1,34 @@
 <?php
-// This file is part of the Savane project
-// <http://gna.org/projects/savane/>
-//
-// $Id: confirmation.php,v 1.61 2004/01/31 00:56:19 yeupou Exp $
-//
-//
-// Copyright 1999-2000 (c) The SourceForge Crew
-//
-//
-// Copyright (C) 2000, 2001, 2002, 2003 Free Software Foundation
-// 
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation; either version 2
-// of the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-//
-//
-//
-//
+# This file is part of the Savane project
+# <http://gna.org/projects/savane/>
+#
+# $Id: confirmation.php,v 1.63 2004/03/06 16:53:35 toddy Exp $
+#
+#
+# Copyright 1999-2000 (c) The SourceForge Crew
+#
+#
+# Copyright (C) 2000, 2001, 2002, 2003 Free Software Foundation
+#
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation; either version 2
+# of the License, or (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+#
+#
+#
+#
 
-require "../include/pre.php";  
+require "../include/pre.php";
 session_require(array('isloggedin'=>'1'));
 require "../include/vars.php";
 
@@ -38,7 +38,7 @@ if ($show_confirm && $rand_hash)
   $HTML->header(array('title'=>_("Registration Complete")));
   $sql="UPDATE groups SET type='$group_type' WHERE group_id='$group_id' AND rand_hash='__$rand_hash'";
   $result=db_query($sql);
-	
+
   $sql="SELECT * FROM groups WHERE group_id='$group_id' AND rand_hash='__$rand_hash'";
   $result=db_query($sql);
 
@@ -104,7 +104,7 @@ if ($show_confirm && $rand_hash)
 }
 else if ($i_agree && $group_id && $rand_hash)
 {
-  // complete the db entries
+  # complete the db entries
   $result=db_query("UPDATE groups SET status='P', "
 		   .	"register_purpose='".htmlspecialchars($form_purpose)."', "
 		   .	"required_software='".htmlspecialchars($form_required_sw)."', "
@@ -122,10 +122,10 @@ else if ($i_agree && $group_id && $rand_hash)
 		 . ' ' . db_error());
     }
 
-  // make the current user an admin
+  # make the current user an admin
   $result = member_add(user_getid(), $group_id, "A");
 
-  // admin    bugs  forums
+  # admin    bugs  forums
   if (!$result)
     {
       exit_error(_("Error"),'Setting you as project admin failed.. ');
@@ -138,25 +138,25 @@ else if ($i_agree && $group_id && $rand_hash)
   $type = db_result($sql_type,0,'name');
   $type_base_host = $project->getTypeBaseHost();
   $type_admin_email_address = $project->getTypeAdminEmailAddress();
-       
-  // get site-specific content. It will define confirmation_gen_email()
+
+  # get site-specific content. It will define confirmation_gen_email()
   utils_get_content("register/confirmation_mail");
 
   $message = confirmation_gen_email ($type_base_host, $user_realname, $user_email, $type_admin_email_address, $form_license, $form_license_other, $form_full_name, $unix_name, $type, $form_purpose, $form_required_sw, $form_comments);
-	
+
   $message_user = "$message"
      ."\n\n\n\n"
      ."*"._("In case you have to register your project again").".\n\n"
      .sprintf(_("Please be aware that if your registration does not fulfill all the requirements, the %s administrators may ask you to register your project again."),$GLOBALS['sys_name'])
-     ._("You can use the following url to do a new registration starting with the values used in this registration process.")."\n"
+     ._("You can use the following URL to do a new registration starting with the values used in this registration process.")."\n"
      ._("Copy and paste AS ONE SINGLE URL the following content:")."\n"
      ."----RERegistration-URL-BEGIN-----\n"
      ."http://".$project->getTypeBaseHost().$GLOBALS['sys_home']."register/basicinfo.php?re_purpose=".rawurlencode($form_purpose)."&re_require_sw=".rawurlencode($form_required_sw)."&re_comments=".rawurlencode($form_comments)."&re_full_name=".rawurlencode($form_full_name)."&re_unix_name=".rawurlencode($unix_name)."\n"
      ."----RERegistration-URL-END-------\n";
 
   $message_admin = "$message";
-   
-  // a mail for the submitter
+
+  # a mail for the submitter
   sendmail_mail($type_admin_email_address,
 		$user_email,
 		"submission of $form_full_name - $type_base_host",
@@ -165,7 +165,7 @@ else if ($i_agree && $group_id && $rand_hash)
 		$type_admin_email_address);
 
 
-  // a mail for the moderators staff
+  # a mail for the moderators staff
   sendmail_mail($user_email,
 		$type_admin_email_address,
 		"submission of $form_full_name - $type_base_host",
@@ -173,16 +173,16 @@ else if ($i_agree && $group_id && $rand_hash)
 		0,0,0,
 		$user_email);
 
-  // special case: the unix_group_name fit the sys_unix_group_name:
-  //   this project must be activated.
+  # special case: the unix_group_name fit the sys_unix_group_name:
+  #   this project must be activated.
   if ($GLOBALS['sys_group_id'] == $group_id)
     {
       $result=db_query("UPDATE groups SET status='A' WHERE group_id='$group_id' AND rand_hash='__$rand_hash'");
     }
-    
+
   $HTML->header(array('title'=>_("Registration Complete")));
-	
-  // get site-specific content
+
+  # get site-specific content
   utils_get_content("register/confirmation");
 
   $HTML->footer(array());
@@ -204,7 +204,7 @@ else
 {
   exit_error('Error',_("This is an invalid state.").' '
 	     ._("Some form variables were missing.").' '
-	     .sprintf(_("If you are certain you entered everything, %s PLEASE %s report to %s including info on your browser and platform configuration."),'<b>','</b>',$GLOBALS['sys_email_address']));
+	     .sprintf(_("If you are certain you entered everything, %sPLEASE%s report to %s including info on your browser and platform configuration."),'<b>','</b>',$GLOBALS['sys_email_address']));
 }
 
 ?>
